%
%
% Directional response, SR(omega,frequency), for the Bergsysund
% floating bridge 3D model.
%
% FRF-analyses for a directional wave field
% Frequency dependent response spectra 
% vectors are imported for sway, heave and roll motion. These response 
% spectra vectors represent the FRF's of desired response parameters scaled
% according to the one-dimesional JONSWAP spectrum, which represents the
% sea state at the site. (Storm event)
% Thus, frequency dependent response spectra are imported, and these are
% combined with a cos-2s spreading function to represent the effect of
% short-crestedness.
%
% The directional response spectrum for a response parameter is determined
% by combining the frequency response function (FRF) with the directional
% wave spectrum, and is thus a two-dimensional function for the wave energy
% spread over the frequency and approach angle domain.
%
% Functions: Bergsoy_Response_spectra_sway_heave_roll.m
%            cos_directional_spreading_function.m
%
%
%
% By Axel Wullf Wathne, 2012.
%

clear all
clc


% Input wave parameters

a  = 2;     % Wave amplitude of oncoming waves
Hs = 2;     % Significant wave height of JONSWAP spectrum
Tp = 7;     % Peak period of the JONSWAP spectrum


% Input parameters for the directional spreading function

n      = 0.01;  % Angular step size
omega0 = 0;     % Mean wave direction
s      = 8;     % Spreading index



% Importing the one-dimensional frequency dependent response spectra for
% sway, heave and roll motion of the floating bridge.

[SRsway,SRheave,SRroll,w,f] = Bergsoy_Response_spectra_sway_heave_roll(a,Hs,Tp);



% Importing the directional spreading function

[Direc, Ns, SumDirec, Omega] = cos_directional_spreading_function(n,omega0,s);



% Combining the functions to obtain response spectra for the response
% parameters

SRswaydirec  = SRsway * Direc;

SRheavedirec = SRheave * Direc;

SRrolldirec  = SRroll * Direc;



% Plots of the directional two-dimensional response spectra

figure(1);
surf(Omega,w,SRswaydirec);
title('Directional response spectrum - Sway');
xlabel('Direction of wave approach, radians');
ylabel('Angular frequency, rad/s');


figure(2);
surf(Omega,w,SRheavedirec);
title('Directional response spectrum - Heave');
xlabel('Direction of wave approach, radians');
ylabel('Angular frequency, rad/s');


figure(3);
surf(Omega,w,SRrolldirec);
title('Directional response spectrum - Roll'); 
xlabel('Direction of wave approach, radians');
ylabel('Angular frequency, rad/s');







