

%
% General frequency response function for the Bergsysund floating bridge 
% model obtained by including a unit load vector in every DOF.
%
% FRF response functions are developed to compare the damped and undamped
% response of the floating bridge model for desired response quantities.
% The script may also be used to graphically compare different response
% parameters against eachother, say for heave motion at different point
% along the bridge span. The real and imaginary terms of the FRF's are also
% ploted.
%
% A desired frequency interval is determined with frequency steps, dw. For
% each frequency step, w(i), the dimensionless hydrodynamic coefficients 
% are determined from interpolation functions. 
% 
% The hydrodynamic coefficients are obtained graphically from Langen, which
% in turn has the coefficients derived from work by Vugts.
%
% The dimensional hydrodynamic coefficients are then applied to extract the
% proper mass, damping and stiffness matrices associated with frequency
% w(i). These matrices are stored in a matrix array with each matrix being
% og size equal to the global degrees of freedom (ndofG x ndofG), and the
% array being the same size as the number of frequency steps in the loop.
% The dynamic equation of motion is established at each frequency interval,
% and inverted to form a direct frequency domain response solution.
% H-matrices are stored for each frequency step and contain the FRF's of
% all DOF's of the dynamic system.
% 
%
% To obtain a FRF for a given response parameter, corresponding response 
% values are extracted from each of the matrices for the response parameter
% of interest. These extracted values are representative for each frequency
% step of the loop, and these values are plotted over the frequency domain
% to form the FRF of the response parameter.
%
%
% Input: MG,CG,KG     - global property matrices
%
%        
%
% Output: FRF - frequency response function of desired response parameters
%
%
%
% Functions: Bergsoy_interpolation_added_mass_heave.m
%            Bergsoy_interpolation_added_mass_sway.m
%            Bergsoy_interpolation_added_mass_roll.m
%            Bergsoy_interpolation_added_mass_surge.m
%            Bergsoy_interpolation_added_mass_pitch.m
%            Bergsoy_interpolation_hydro_damping_heave.m
%            Bergsoy_interpolation_hydro_damping_sway.m
%            Bergsoy_interpolation_hydro_damping_roll.m
%            Bergsoy_interpolation_hydro_damping_surge.m
%            Bergsoy_interpolation_hydro_damping_pitch.m
%            
%
% 
% By Axel Wullf Wathne, 2012.
%

clear all
clc



% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

L    =  840;      % length of bridge in x-direction  
B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
tds  = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tws  = 0.01;      % thickness of side walls of the superstructure
Nsup = 25;        % number of nodes along the superstructure  


% Properties of the PC-sub system

Lp = 30;        % length of pontoon
Bp = 20;        % width of pontoon in the fluid
hp = 7;         % height of pontoon
td = 0.35;      % thickness of pontoon top and bottom deck
tw = 0.55;      % thickness of pontoon walls
Awp= Lp*Bp;     % water plane area

Lc = 1.20;      % length of connector rod
ry = 1.00;      % outer radius of connector rod, assumed circular      
tc = 0.05;      % thickness of connector rod, assumed circular

Ap = 2*(Bp*td+(hp-(2*td))*tw);  % Area of pontoon cross-section, assumed hollow quadratic section
Ac = 4*pi*(2*ry*tc - tc^2);     % Area of four connector cross-section, assumed hollow circular section   

Asup = (2*(h-tds-ts)*tws)+(B*(tds+ts)); % Area of superstructre cross-section, assumed hollow quadratic section [m2]


denp = 2500;                    % Density of concrete
denS = 7500;                    % Density of steel


g    = 9.81;                    % Gravitational constant
rhow = 1025;                    % Density of salt water


% Evaluation of the draft of a pontoon

% It is assumed that the weight of the overlying structure is equally
% distributed across the pontoons. Such that the weigth on a single pontoon
% is equal to the weight of two superstructure elements, the connector rod
% element and the two pontoon elements.


Lesup = L/(Nsup-1);     % Approximate length of each superstructure element

W  = (3*(Lesup*Asup*denS) + (Lp*Ap*denp) + (Lc*Ac*denS))*g;  % Weight distributed to
                                                              % one pontoon from the
                                                              % above structure.

kB = rhow*g*Bp*Lp;       % Buoyancy stiffness 
                                                            
d  = W/kB;               % Draft of the pontoon  



% Degrees of freedom

ndofsup =  150;
ndofpc  =   36;
ndofG   =  360;
npc     =    7;

% Define matrices of size equal to the degrees of freedom of the system
% These matrices must match the number of DOF's of the system after the
% boundary conditions are introduced and the system DOF's reduced.

ndofres  = 9;               % Number of restrained DOF's
ndofGred = ndofG - ndofres; % Reduced number of DOF's for the global system

 
% Define the frequency step for the FRF

dw = 0.1;          % Frequency step
wmax = 5;           % Maximum value of the angular frequency
Nw = fix(wmax/dw);  % Fix to make sure Nw is without decimals

 
% Writing frequency step vector, w, and vectors for the FRF values 

w            = (1:Nw)*dw;
FRFsway1     = zeros(Nw,1);
FRFsway2     = zeros(Nw,1);
FRFheave1    = zeros(Nw,1);
FRFheave2    = zeros(Nw,1);
FRFroll1     = zeros(Nw,1);
FRFroll2     = zeros(Nw,1);
FRFswayreal  = zeros(Nw,1);
FRFswayimag  = zeros(Nw,1);
FRFheavereal = zeros(Nw,1);
FRFheaveimag = zeros(Nw,1);
FRFrollreal  = zeros(Nw,1);
FRFrollimag  = zeros(Nw,1);
f            = w./(2*pi);         % Vector of corresponding frequencies in Hz
Runit        = ones(ndofGred,1);  % Unit load vector


% Writing matrix arrays for storing the property matrices of the system for 
% each frequency step

D1 = zeros(ndofGred,ndofGred,length(w));
D2 = zeros(ndofGred,ndofGred,length(w));
H1 = zeros(ndofGred,ndofGred,length(w));
H2 = zeros(ndofGred,ndofGred,length(w));


% Extracting the frequency dependent hydrodynamic coefficients as vectors
% according to the input frequency vector, w.

% Determine frequency dependent hydrodynamic mass in heave motion
    
     [mzz,Mzz] = Bergsoy_interpolation_added_mass_heave(w,Bp,g,d);
     
     
% Determine frequency dependent hydrdynamic mass in sway motion

     [myy,Myy] = Bergsoy_interpolation_added_mass_sway(w,Bp,g,d);
     
     
% Determine frequency dependent hydrodynamic mass in roll motion
    
     [mrr,Mrr] = Bergsoy_interpolation_added_mass_roll(w,Bp,g,d);  
     
     
% Determine frequency dependent hydrodynamic mass in surge motion 
    
     [mxx,Mxx] = Bergsoy_interpolation_added_mass_surge(w,Lp,g,d);  
     
    

    
    
    
% Determine frequency dependent hydrodynamic damping in heave motion
   
    [czz,Czz] = Bergsoy_interpolation_hydro_damping_heave(w,Bp,g,d); 
    

% Determine frequency dependent hydrodynamic damping in sway motion

    [cyy,Cyy] = Bergsoy_interpolation_hydro_damping_sway(w,Bp,g,d);
    
    
% Determine frequency dependent hydrodynamic damping in roll motion
    
    [crr,Crr] = Bergsoy_interpolation_hydro_damping_roll(w,Bp,g,d); 
    
    
% Determine frequency dependent hydrodynamic damping in surge motion

   [cxx,Cxx] = Bergsoy_interpolation_hydro_damping_surge(w,Lp,g,d);
   
   


   
for i = 1:Nw;
         
    
         
   % Importing the global mass, damping and stiffness matrices for the 
   % global 3D floating bridge model associated with frequency w(i).
    
    [MG,CG,KG] = Bergsoy_G_global_property_matrices(ndofsup,ndofpc,ndofG,npc,Myy(i),Mzz(i),Mrr(i),Mxx(i),Cyy(i),Czz(i),Crr(i),Cxx(i));
   
    
    
   % Introducing boundary conditions of a simply supported bridge construction
   % with additional restraints on the torsional DOF's and rotation about 
   % the vertical axis at each end.
   
   % For the original node numbering of the global model the restrained
   % DOF's are 1,2,3,4,5,146,147,148&149. As the node numbering is changed to
   % decrease the bandwidth of the property matrices, the restrained DOF's
   % correspond to 1,2,3,4,5,356,357,358 & 359.
   
   k = [1 2 3 4 5 356 357 358 359]; 

   MGred = MG;
   CGred = CG;
   KGred = KG;
   

   MGred(k,:) = [];
   MGred(:,k) = [];

   CGred(k,:) = [];
   CGred(:,k) = [];

   KGred(k,:) = [];
   KGred(:,k) = [];
   
   
    
   % Invers of the FRF for frequency w(i) including the hydrodynamic damping.
   
    D1(:,:,i) = (KGred - (w(i)^2)*MGred + sqrt(-1)*w(i)*CGred);
    
    
   % Invers of the FRF for frequency w(i) excluding the hydrodynamic damping.
   
    D2(:,:,i) = (KGred - (w(i)^2)*MGred);
    
 
   % Determination of the FRF's as the inverse of D1 and D2.
   
   % For each frequency step w(i) a matrix D and its inverse H is produced.
   % This matrix, H, represents the response of the system for all DOF's at
   % frequency equal to w(i). To construct a frequency response function
   % for a single response parameter over a range of frequencies, the
   % response value of that response parameter is to be extracted for each
   % frequency step. This is done by extracting abs(H(n,n,i)) for response
   % variable associated with DOF number n, and storing this value in the
   % FRFw vector. At each frequency step, such a value is stored in the
   % FRFW vector, which is finally ploted against the frequency steps.
    
    H1(:,:,i) = inv(D1(:,:,i));      % Writing inverse of D-matrices to obtain
    H2(:,:,i) = inv(D2(:,:,i));      % the FRF-matrices of the damped and undamped
                                     % system responses.
    
    
    % FRF sway motion
    FRFsway1(i)  = abs((H1(74,:,i))*Runit);       % add in the frequency dependent H1-values
                                                % For horizontal damped response in the center of
                                                % the bridge, D(74), for damped system.
    
                                       
    FRFsway2(i)  = abs((H2(74,:,i))*Runit);       % add in the frquency dependent H2-values 
                                                % for horizontal undamped response in the center of 
                                                % the bridge, D(74), for undamped system.
                                  
    
                                  
    % FRF heave motion
    FRFheave1(i)  = abs((H1(75,:,i))*Runit);      % add in the frequency dependent H1-values
                                                % For vertical damped response in the center of
                                                % the bridge, D(75), for damped system.
    
                                          
    FRFheave2(i)  = abs((H2(75,:,i))*Runit);      % add in the frquency dependent H2-values 
                                                % for vertical undamped response in the center of 
                                                % the bridge, D(75), for undamped system.
    
    
    
                                      
    % FRF roll motion
    FRFroll1(i)  = abs((H1(76,:,i))*Runit);       % add in the frequency dependent H1-values
                                                % For torsional damped response in the center of
                                                % the bridge, D(76), for damped system.
    
                                        
    FRFroll2(i)  = abs((H2(76,:,i))*Runit);       % add in the frquency dependent H2-values
                                                % for vertical undamped response in the center of 
                                                % the bridge, D(76), for undamped system.
    
    
%    FRFswayreal(i)   = real(H1(74,:,i)*Runit);    
%     
%    FRFswayimag(i)   = imag(H1(74,:,i)*Runit);                                                
%                                                 
%    FRFheavereal(i)  = real(H1(75,:,i)*Runit);    
%     
%    FRFheaveimag(i)  = imag(H1(75,:,i)*Runit); 
%    
%    FRFrollreal(i)   = real(H1(76,:,i)*Runit);    
%     
%    FRFrollimag(i)   = imag(H1(76,:,i)*Runit);   
%     
end
 

% Plots of sway, heave and roll FRF's

figure(1);
h = semilogy(w,FRFsway1,'b',w,FRFsway2,'r',w,FRFswayreal,'g',w,FRFswayimag,'m');
title('FRF Sway Response - Nodal Point no. 13 - Center point');
xlabel('Frequency (rad/s)','FontSize',15)
ylabel('Horizontal Displacement Response','FontSize',15)
legend('Damped system - absolute value','Undamped system - absolute value','Damped system - real part','Damped system - imaginary part')

figure(2);
h = semilogy(w,FRFheave1,'b',w,FRFheave2,'r',w,FRFheavereal,'g',w,FRFheaveimag,'m');
title('FRF Heave Response - Nodal Point no. 13 - Center point');
xlabel('Frequency (rad/s)','FontSize',15)
ylabel('Vertical Displacement Response','FontSize',15)
legend('Damped system - absolute value','Undamped system - absolute value','Damped system - real part','Damped system - imaginary part');

figure(3);
h = semilogy(w,FRFroll1,'b',w,FRFroll2,'r');
title('FRF Roll Response - Nodal Point no. 13 - Center point');
xlabel('Frequency (rad/s)','FontSize',15)
ylabel('Torsional Displacement Response','FontSize',15)
legend('Damped system - absolute value','Undamped system - absolute value','Damped system - real part','Damped system - imaginary part')






