

%
% Development of FRF's scaled with frequency dependent load amplitude in
% sway, heave and roll motion. 
%
%
%
% A desired frequency interval is determined with frequency steps, dw. For
% each frequency step, w(i), the dimensionless hydrodynamic coefficients 
% are determined from interpolation functions. 
% 
% The hydrodynamic coefficients are obtained graphically from Langen, which
% in turn has the coefficients derived from work by Vugts.
%
% The dimensional hydrodynamic coefficients are then applied to extract the
% proper mass, damping and stiffness matrices associated with frequency
% w(i). These matrices are stored in a matrix array with each matrix being
% og size equal to the global degrees of freedom (ndofG x ndofG), and the
% array being the same size as the number of frequency steps in the loop.
% The dynamic equation of motion is established at each frequency interval,
% and inverted to form a direct frequency domain response solution.
% H-matrices are stored for each frequency step and contain the FRF's of
% all DOF's of the dynamic system.
% 
%
% To obtain a FRF for a given response parameter, corresponding response 
% values are extracted from each of the matrices for the response parameter
% of interest. These extracted values are representative for each frequency
% step of the loop, and these values are plotted over the frequency domain
% to form the FRF of the response parameter.
%
%
% Input: MG,CG,KG     - global property matrices
%
%        
%
% Output: FRF - frequency response function of desired response parameters
%
%
%
% Functions: Bergsoy_interpolation_added_mass_heave.m
%            Bergsoy_interpolation_added_mass_sway.m
%            Bergsoy_interpolation_added_mass_roll.m
%            Bergsoy_interpolation_added_mass_surge.m
%            Bergsoy_interpolation_added_mass_pitch.m
%            Bergsoy_interpolation_hydro_damping_heave.m
%            Bergsoy_interpolation_hydro_damping_sway.m
%            Bergsoy_interpolation_hydro_damping_roll.m
%            Bergsoy_interpolation_hydro_damping_surge.m
%            Bergsoy_interpolation_hydro_damping_pitch.m
%            
%
% 
% By Axel Wullf Wathne, 2012.
%

clear all
clc



% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

L    =  840;      % length of bridge in x-direction  
B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
tds  = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tws  = 0.01;      % thickness of side walls of the superstructure
Nsup = 25;        % number of nodes along the superstructure  


% Properties of the PC-sub system

Lp = 30;        % length of pontoon
Bp = 20;        % width of pontoon in the fluid
hp = 7;         % height of pontoon
td = 0.35;      % thickness of pontoon top and bottom deck
tw = 0.55;      % thickness of pontoon walls


Lc = 1.20;      % length of connector rod
ry = 1.00;      % outer radius of connector rod, assumed circular      
tc = 0.05;      % thickness of connector rod, assumed circular

dx   = Lp/4;    % length of hydroelastic pontoon elements, 5 elements.
Awp  = dx*Bp;   % water plane are of the pontoons elements

Ap = 2*(Bp*td+(hp-(2*td))*tw);  % Area of pontoon cross-section, assumed hollow quadratic section
Ac = 4*pi*(2*ry*tc - tc^2);     % Area of four connector cross-section, assumed hollow circular section   

Asup = (2*(h-tds-ts)*tws)+(B*(tds+ts)); % Area of superstructre cross-section, assumed hollow quadratic section [m2]


denp = 2500;                    % Density of concrete
denS = 7500;                    % Density of steel


g    = 9.81;                    % Gravitational constant
rhow = 1025;                    % Density of salt water


% Evaluation of the draft of a pontoon

% It is assumed that the weight of the overlying structure is equally
% distributed across the pontoons. Such that the weigth on a single pontoon
% is equal to the weight of two superstructure elements, the connector rod
% element and the two pontoon elements.


Lesup = L/(Nsup-1);     % Approximate length of each superstructure element

W  = (3*(Lesup*Asup*denS) + (Lp*Ap*denp) + (Lc*Ac*denS))*g;  % Weight distributed to
                                                              % one pontoon from the
                                                              % above structure.

kB = rhow*g*Bp*Lp;       % Buoyancy stiffness 
                                                            
d  = W/kB;               % Draft of the pontoon  



% Degrees of freedom

ndofsup =  150;
ndofpc  =   36;
ndofG   =  360;
npc     =    7;

% Define matrices of size equal to the degrees of freedom of the system
% These matrices must match the number of DOF's of the system after the
% boundary conditions are introduced and the system DOF's reduced.

ndofres  = 9;               % Number of restrained DOF's
ndofGred = ndofG - ndofres; % Reduced number of DOF's for the global system

 
% Define the frequency step for the FRF

% dw = 0.05;          % Frequency step
% wmax = 5;           % Maximum value of the angular frequency
% Nw = fix(wmax/dw);  % Fix to make sure Nw is without decimals

 
% Writing frequency step vector, w, and vectors for the FRF values 

wh= [0:0.01:1.99,2:0.05:5];
Nw = length(wh);
FRFheave1    = zeros(Nw,1);
FRFheave2    = zeros(Nw,1);
FRFheave3    = zeros(Nw,1);
FRFheave4    = zeros(Nw,1);
FRFheave5    = zeros(Nw,1);
w            = zeros(length(wh),1);
f            = w./(2*pi);         % Vector of corresponding frequencies in Hz


% Importing a load transfer and spatially scaled load vector in heave

[RG] = Bergsoy_load_vector(Nw,wh);


% Writing matrix arrays for storing the property matrices of the system for 
% each frequency step

D1 = zeros(ndofGred,ndofGred);
%D2 = zeros(ndofGred,ndofGred);
H1 = zeros(ndofGred,ndofGred,Nw);
%H2 = zeros(ndofGred,ndofGred,Nw);

% qsway  = zeros(1,Nw);
% qheave = zeros(1,Nw);
% qroll  = zeros(1,Nw);


% Creating a load vector array for each wave angle of approach step, dom, 
% with each column in the vector array corresponding to a frequency step,
% dw.
   
   
   
% Introducing the total load vector into the FRF analysis

for i = 1:length(wh);
    
    
   % Defining the frequency step for the frequency vector
    
    w(i) = wh(i); 
    f(i) = w(i)/(2*pi);
    
    
% Extracting the frequency dependent hydrodynamic coefficients as vectors
% according to the input frequency vector, w.

% Determine frequency dependent hydrodynamic mass in heave motion
    
     [mzz,Mzz(i)] = Bergsoy_interpolation_added_mass_heave(w(i),Bp,g,d);
     
     
% Determine frequency dependent hydrdynamic mass in sway motion

     [myy,Myy(i)] = Bergsoy_interpolation_added_mass_sway(w(i),Bp,g,d);
     
     
% Determine frequency dependent hydrodynamic mass in roll motion
    
     [mrr,Mrr(i)] = Bergsoy_interpolation_added_mass_roll(w(i),Bp,g,d);  
     
     
% Determine frequency dependent hydrodynamic mass in surge motion 
    
     [mxx,Mxx(i)] = Bergsoy_interpolation_added_mass_surge(w(i),Lp,g,d);  
     


    
    
% Determine frequency dependent hydrodynamic damping in heave motion
   
    [czz,Czz(i)] = Bergsoy_interpolation_hydro_damping_heave(w(i),Bp,g,d); 
    

% Determine frequency dependent hydrodynamic damping in sway motion

    [cyy,Cyy(i)] = Bergsoy_interpolation_hydro_damping_sway(w(i),Bp,g,d);
    
    
% Determine frequency dependent hydrodynamic damping in roll motion
    
    [crr,Crr(i)] = Bergsoy_interpolation_hydro_damping_roll(w(i),Bp,g,d); 
    
    
% Determine frequency dependent hydrodynamic damping in surge motion

   [cxx,Cxx(i)] = Bergsoy_interpolation_hydro_damping_surge(w(i),Lp,g,d);
   

     
         
   % Importing the global mass, damping and stiffness matrices for the 
   % global 3D floating bridge model associated with frequency w(i).
    
    [MG,CG,KG] = Bergsoy_G_global_property_matrices(ndofsup,ndofpc,ndofG,npc,Myy(i),Mzz(i),Mrr(i),Mxx(i),Cyy(i),Czz(i),Crr(i),Cxx(i));
   
    
    
   % Introducing boundary conditions of a simply supported bridge construction
   % with additional restraints on the torsional DOF's and rotation about 
   % the vertical axis at each end.
   
   % For the original node numbering of the global model the restrained
   % DOF's are 1,2,3,4,5,146,147,148&149. As the node numbering is changed to
   % decrease the bandwidth of the property matrices, the restrained DOF's
   % correspond to 1,2,3,4,5,356,357,358 & 359.
   
   k = [1 2 3 4 5 356 357 358 359]; 

   MGred = MG;
   CGred = CG;
   KGred = KG;
   Rred  = RG(:,i);    % Column in the load vector corresponding to frequency
                        % step number i.

   MGred(k,:) = [];
   MGred(:,k) = [];

   CGred(k,:) = [];
   CGred(:,k) = [];

   KGred(k,:) = [];
   KGred(:,k) = [];
   
   Rred (k) = [];
   
    
   % Invers of the FRF for frequency w(i) including the hydrodynamic damping.
   
    D1 = (KGred - (w(i)^2)*MGred + sqrt(-1)*w(i)*CGred);
    
    
   % Invers of the FRF for frequency w(i) excluding the hydrodynamic damping.
   
    %D2 = (KGred - (w(i)^2)*MGred);
    
 
   % Determination of the FRF's as the inverse of D1 and D2.
   
   % For each frequency step w(i) a matrix D and its inverse H is produced.
   % This matrix, H, represents the response of the system for all DOF's at
   % frequency equal to w(i). To construct a frequency response function
   % for a single response parameter over a range of frequencies, the
   % response value of that response parameter is to be extracted for each
   % frequency step. This is done by extracting abs(H(n,n,i)) for response
   % variable associated with DOF number n, and storing this value in the
   % FRFw vector. At each frequency step, such a value is stored in the
   % FRFW vector, which is finally ploted against the frequency steps.
    
    H1(:,:,i) = inv(D1);      % Writing inverse of D-matrices to obtain
   % H2(:,:,i) = inv(D2);      % the FRF-matrices of the damped and undamped
                              % system responses.
    
    
    
                                  
    % FRF heave motion
    FRFheave1(i)  = abs((H1(160,:,i))*Rred);     
                                       
    %FRFheave2(i)  = abs((H2(160,:,i))*Rred);     
    
    FRFheave3(i)  = abs((H1(64,:,i))*Rred);     
                                       
    %FRFheave4(i)  = abs((H2(64,:,i))*Rred);     
    
    FRFheave5(i)  = abs((H1(16,:,i))*Rred); 
    
                        
end
 

% Plots of heave FRF's

% figure(1);
% h = semilogy(w,FRFheave1,'b',w,FRFheave2,'r');
% title('Spatially Scaled FRFs for Damped and Un-Damped Heave Motion at Mid-Point','FontSize',13);
% xlabel('Frequency (rad/s)','FontSize',13)
% ylabel('Vertical Response','FontSize',13)
% legend('Damped system - absolute value','Undamped system')
% 
% figure(2);
% h = semilogy(w,FRFheave1,'b',w,FRFheave3,'r');
% title('FRF Heave Response - Mid-Point and L/4-Point','FontSize',13);
% xlabel('Frequency (rad/s)','FontSize',13)
% ylabel('Vertical Response','FontSize',13)
% legend('Mid-Point','L/4_point')

figure(3);
plot(w,FRFheave1,'b',w,FRFheave3,'g',w,FRFheave5,'m');
title('Spatially Scaled FRFs for Heave Motion at Mid-Point, L/4-Point & L/8-Point','FontSize',13);
xlabel('Frequency (rad/s)','FontSize',13)
ylabel('Vertical Response  [m]','FontSize',13)
legend('Heave at Mid-Point','Heave at L/4-Point','Heave at L/8-Point')




