function [MG,CG,KG] = Bergsoy_G_global_property_matrices(ndofsup,ndofpc,ndofG,npc,Myy,Mzz,Mrr,Mxx,Cyy,Czz,Crr,Cxx)

%
% Assembly of the global mass, damping and stiffness matrices for the
% 3-dimensional model of Bergsysund floating bridge.
%
% The property matrices represent an arched superstructure of length 840m
% in the x-direction and a radius of 1300m. The superstructure is modelled 
% by use of 24 structural beam elements with constant cross-sectional area.
% 7 pontoons are connected along the bridge superstructure at equividistant
% points. The orientation of each pontoon is normal to the superstructure
% at the point of assembly.
%
% The complete property matrices are assembled from the superstructure
% sub-system, and the seven pontoon-connector sub-systems. All the
% sub-systems are transformed to the global coordinate axes, so the
% connectivity matrices used for the assembly contain only one-to-one
% relations between the sub-system DOF's and the full model (global) DOF's.
%
%
% Input:   asupG - connectivity matrix for the superstructure sub-system
%                  DOF's in global coordinates to the model DOF's.
%           apcG - connectivity matrices for each of the pc-sub-system DOF's
%                  in global coordinates to the model DOF's.
% MpcG,CpcG,KpcG - property matrices for the pc-sub-system in global
%                  coordinates.
%    MsupG,KsupG - property matrices for the superstructure sub-system in
%                  global coordinates.
%
% Output: 
%       MG,CG,KG - property matrices for the 3D floating bridge model in
%                  the global coordinate system.
%
%
%
% Functions: Bergsoy_G_connectivity_matrices_global_assembly.m
%            Bergsoy_pc_transformation_mass_damping_stiffness.m
%            Bergsoy_superstructure_assembly_mass_stiffness.m
%
%
% By Axel Wullf Wathne, 2012.
%



% Importing the connectivity matrices for the global assembly

[asupG,apcG] = Bergsoy_G_connectivity_low_bandwidth(ndofsup,ndofpc,npc,ndofG);

% The connectivity matrix linking the superstructure DOF's to the global, 
% asupG is one singel matrix [150x360]. The connectivty matrices for the
% pontoon-connector sub-system are stored in a matrix array [36x360x7].


% Importing the sub-system property matrices, related to global coordinates

[MpcG,CpcG,KpcG] = Bergsoy_pc_transformation_mass_damping_stiffness(ndofpc,Myy,Mzz,Mrr,Mxx,Cyy,Czz,Crr,Cxx);


[MsupG,KsupG] = Bergsoy_superstructure_assembly_mass_stiffness;


% The property matrices of the superstructure sub-system are single
% matrices [150x150]. The property matrices of the pc-sub-system are stored
% in matrix arrays for each of the pc-sub-system [36x36x7]




% The contribution from the bridge superstructure to the total property
% matrices of the floating bridge model is determined through the superstructure
% sub-system property matrices, and the connectivity matrices linking the
% DOF's of the sub-system to the global DOF's.


    MGsup = asupG'*MsupG*asupG; 
    KGsup = asupG'*KsupG*asupG; 



% Contribution from each of the pontoon-connectore sub-systems (1-7) to the
% global property matrices for the bridge model is determined through the
% transformed property matrices of the each pc-sub-system and the corresponding
% connectivity matrices linking the DOF's of each of the sub-systems to the
% global DOF's of the model.

MGpc = zeros(ndofG,ndofG,npc);  % Matrix arrays for the contribution from  
CGpc = zeros(ndofG,ndofG,npc);  % each of the PC-sub-systems.
KGpc = zeros(ndofG,ndofG,npc);

MGpctot = zeros(ndofG,ndofG);   % Matrices for storing of the total 
CGpctot = zeros(ndofG,ndofG);   % contribution from the pc-sub-systems.
KGpctot = zeros(ndofG,ndofG);


for i = 1 : npc;                % Loop over all PC-sub-systems
    
    MGpc(:,:,i) = apcG(:,:,i)'*MpcG(:,:,i)*apcG(:,:,i);
     
    CGpc(:,:,i) = apcG(:,:,i)'*CpcG(:,:,i)*apcG(:,:,i);
    
    KGpc(:,:,i) = apcG(:,:,i)'*KpcG(:,:,i)*apcG(:,:,i);
    
    MGpctot = MGpctot + MGpc(:,:,i);
    CGpctot = CGpctot + CGpc(:,:,i);
    KGpctot = KGpctot + KGpc(:,:,i);
    
end


    % The global property matrices for the floating bridge model are obtained 
    % by summation of the superstructure and pontoon-connector sub-system
    % contributions.
    
    

    MG = MGsup + MGpctot;
    
    CG =         CGpctot;

    KG = KGsup + KGpctot;
    
    
 

end
    
    
    
    
    
    
    
    