function [H] = Bergsoy_H_matrix(dw,Nw)

%
% Determination of the H-matrix storing the properties of the
% fluid-structure system. Both structural, hydrostatic and hydrodynamic
% effects are included. H-matrices are reduced according to the restrained
% DOF's.
%
%
% Input: MG,CG,KG     - global property matrices
%
%        
%
% Output: H(w) - frequency dependent system properties
%
%
%
% Functions: Bergsoy_interpolation_added_mass_heave.m
%            Bergsoy_interpolation_added_mass_sway.m
%            Bergsoy_interpolation_added_mass_roll.m
%            Bergsoy_interpolation_added_mass_surge.m
%            Bergsoy_interpolation_added_mass_pitch.m
%            Bergsoy_interpolation_hydro_damping_heave.m
%            Bergsoy_interpolation_hydro_damping_sway.m
%            Bergsoy_interpolation_hydro_damping_roll.m
%            Bergsoy_interpolation_hydro_damping_surge.m
%            Bergsoy_interpolation_hydro_damping_pitch.m
%            
%
% 
% By Axel Wullf Wathne, 2012.
%



% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

L    =  840;      % length of bridge in x-direction  
B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
tds  = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tws  = 0.01;      % thickness of side walls of the superstructure
Nsup = 25;        % number of nodes along the superstructure  


% Properties of the PC-sub system

Lp = 30;        % length of pontoon
Bp = 20;        % width of pontoon in the fluid
hp = 7;         % height of pontoon
td = 0.35;      % thickness of pontoon top and bottom deck
tw = 0.55;      % thickness of pontoon walls

Lc = 1.20;      % length of connector rod
ry = 1.00;      % outer radius of connector rod, assumed circular      
tc = 0.05;      % thickness of connector rod, assumed circular

Ap = 2*(Bp*td+(hp-(2*td))*tw);  % Area of pontoon cross-section, assumed hollow quadratic section
Ac = 4*pi*(2*ry*tc - tc^2);     % Area of four connector cross-section, assumed hollow circular section   

Asup = (2*(h-tds-ts)*tws)+(B*(tds+ts)); % Area of superstructre cross-section, assumed hollow quadratic section [m2]


denp = 2500;                    % Density of concrete
denS = 7500;                    % Density of steel


g    = 9.81;                    % Gravitational constant
rhow = 1025;                    % Density of salt water


% Evaluation of the draft of a pontoon

% It is assumed that the weight of the overlying structure is equally
% distributed across the pontoons. Such that the weigth on a single pontoon
% is equal to the weight of two superstructure elements, the connector rod
% element and the two pontoon elements.


Lesup = L/(Nsup-1);     % Approximate length of each superstructure element

W  = (3*(Lesup*Asup*denS) + (Lp*Ap*denp) + (Lc*Ac*denS))*g;  % Weight distributed to
                                                              % one pontoon from the
                                                              % above structure.

kB = rhow*g*Bp*Lp;       % Buoyancy stiffness 
                                                            
d  = W/kB;               % Draft of the pontoon  


% Degrees of freedom

ndofsup =  150;
ndofpc  =   36;
ndofG   =  360;
npc     =    7;

% Define matrices of size equal to the degrees of freedom of the system
% These matrices must match the number of DOF's of the system after the
% boundary conditions are introduced and the system DOF's reduced.

ndofres  = 9;               % Number of restrained DOF's
ndofGred = ndofG - ndofres; % Reduced number of DOF's for the global system


% Defining the frequency range

w = (1:Nw)*dw;


% Writing matrix arrays for storing the property matrices of the system for 
% each frequency step

H = zeros(ndofG,ndofG,Nw);


% Extracting the frequency dependent hydrodynamic coefficients as vectors
% according to the input frequency vector, w.

% Determine frequency dependent hydrodynamic mass in heave motion
    
     [mzz,Mzz] = Bergsoy_interpolation_added_mass_heave(w,Bp,g,d);
     
     
% Determine frequency dependent hydrdynamic mass in sway motion

     [myy,Myy] = Bergsoy_interpolation_added_mass_sway(w,Bp,g,d);
     
     
% Determine frequency dependent hydrodynamic mass in roll motion
    
     [mrr,Mrr] = Bergsoy_interpolation_added_mass_roll(w,Bp,g,d);  
     
     
% Determine frequency dependent hydrodynamic mass in surge motion 
    
     [mxx,Mxx] = Bergsoy_interpolation_added_mass_surge(w,Lp,g,d);  
     
    

    
% Determine frequency dependent hydrodynamic damping in heave motion
   
    [czz,Czz] = Bergsoy_interpolation_hydro_damping_heave(w,Bp,g,d); 
    

% Determine frequency dependent hydrodynamic damping in sway motion

    [cyy,Cyy] = Bergsoy_interpolation_hydro_damping_sway(w,Bp,g,d);
    
    
% Determine frequency dependent hydrodynamic damping in roll motion
    
    [crr,Crr] = Bergsoy_interpolation_hydro_damping_roll(w,Bp,g,d); 
    
    
% Determine frequency dependent hydrodynamic damping in surge motion

   [cxx,Cxx] = Bergsoy_interpolation_hydro_damping_surge(w,Lp,g,d);
  
   
   
for i = 1:length(w);
         
   % Importing the global mass, damping and stiffness matrices for the 
   % global 3D floating bridge model associated with frequency w(i).
    
    [MG,CG,KG] = Bergsoy_G_global_property_matrices(ndofsup,ndofpc,ndofG,npc,Myy(i),Mzz(i),Mrr(i),Mxx(i),Cyy(i),Czz(i),Crr(i),Cxx(i));
  
  
    
   % Introducing boundary conditions of a simply supported bridge construction
   % with additional restraints on the torsional DOF's and rotation about 
   % the vertical axis at each end.
   
   % For the original node numbering of the global model the restrained
   % DOF's are 1,2,3,4,5,146,147,148&149. As the node numbering is changed to
   % decrease the bandwidth of the property matrices, the restrained DOF's
   % correspond to 1,2,3,4,5,356,357,358 & 359.
   
%    k = [1 2 3 4 5 356 357 358 359]; 
% 
   MGred  = MG;
   CGred  = CG;
   KGred  = KG;
   
  

%    MGred(k,:) = [];
%    MGred(:,k) = [];
% 
%    CGred(k,:) = [];
%    CGred(:,k) = [];
% 
%    KGred(k,:) = [];
%    KGred(:,k) = [];
%    
   
    
   % Invers of the H-matrix for frequency w(i) including the hydrodynamic damping.
   
    D1 = (KGred - (w(i)^2)*MGred + (sqrt(-1))*w(i)*CGred);
    
    
   % For each frequency step w(i) a matrix D and its inverse H is produced.
   % This matrix, H, represents the response of the system for all DOF's at
   % frequency equal to w(i). 
    
    H(:,:,i) = inv(D1); 
    
    

end


end




