%
% Response spectrum of the Bergsysund floating bridge model
%
% A response spectrum for the 3D Bergsysund floating bridge model is
% developed as function of frequency. The response spectrum at frequency
% step w(i) is expressed as a matrix [ndofG x ndofG], ndofG = 360.
%
% The response spectrum is given as Sr(w) = H(w)SQ(w)H(w)'
%
%
% By Axel Wullf Wathne, 2012
%

% Time intervall for evaluation of response parameters

T = 3600;       % 3600 sec = 1 hour

% Peak factor for evaluation of extreme values

kp = 1;


% JONSWAP spectrum parameters

s=3;       % Spreading index
Hs=1;       % Significant wave height
Tp=3;       % Peak period


% Frequency domain

dw   = 0.25;             % Frequency step
wmax = 1;               % Maximum frequency
Nw   = fix(wmax/dw);


% Importing the load spectrum of the bridge. The terms of the spectrum are
% allocated to the nodal numbering of the floating bridge model according
% to the low bandwidth connectivity matrices.

[SQ] = Bergsoy_load_spectrum(s,dw,Nw,Hs,Tp);


% Importing the H-matrix of the fluid-structure system. This matrix array
% have size equal to the global DOF's and the frequency steps of the
% analysis. The H-matrix is developed by use of the low bandwidth
% connectivity matrices for linking the element and global DOF's.

[H] = Bergsoy_H_matrix(dw,Nw);

% NB! Boundary conditions may already be introduced to the H-matrix array

% Introducing boundary conditions of a simply supported bridge construction
% with additional restraints on the torsional DOF's and rotation about 
% the vertical axis at each end.
    
% For the original node numbering of the global model the restrained
% DOF's are 1,2,3,4,5,146,147,148&149. As the node numbering is changed to
% decrease the bandwidth of the property matrices, the restrained DOF's
% correspond to 1,2,3,4,5,356,357,358 & 359.
   
   k = [1 2 3 4 5 356 357 358 359]; 

   SQred = SQ;
   Hred = H;
   
  
   SQred(k,:,:) = [];
   SQred(:,k,:) = [];

   Hred(k,:,:) = [];
   Hred(:,k,:) = [];

   
% Establishing the global response spectrum matrices for each frequency
% step in the anaylsis.

SR = zeros(length(SQred),length(SQred),Nw);

w  = zeros(1,Nw);

for i = 1:Nw;
    
w(i) = i*dw;
    
SR(:,:,i) = Hred(:,:,i).*SQred(:,:,i).*ctranspose(Hred(:,:,i));

end


% Estimation of maxiumum heave response at mid-node. Estimating the
% response in DOF no. 178 associated with the mid-node at the pontoon
% connected at the bridge mid-point. This response is assumed to be close
% to identical with the bridge deck response at mid-node due to high
% stiffness of the connector rod. Also, evaluating the response of DOF no.
% 160, as this is the heave response directly above the mid-point of the
% centre pontoon and represents the heave response at the mid point of the
% bridge span.

% Writing a frequency reponse vector of the response

h160 = zeros(1,Nw);     % Response vector for DOf 160
h178 = zeros(1,Nw);     % Response vector for DOF 178
h178a= zeros(1,Nw);     % Auto-specter for DOF 178


for i=1:Nw;
    
    h178a(i) = SR(178,178,i);
    
    for m = length(SR);
        
    h160(i) = h160(i) + SR(160,m,i)/sqrt(SR(m,m,i));
        
    h178(i) = h178(i) + SR(178,m,i)/sqrt(SR(m,m,i));
    
    end
    
end


% Plot of the heave response as function of frequency

figure(2)
plot(w,abs(h178),'b',w,real(h178),'y',w,imag(h178),'r');
title('Heave Response Spectrum Mid-Node of Centre Pontoon');
xlabel('Frequency of motion - [rad/s] ');
ylabel('Vertical displacement - [m] ');
legend('Absolute value','Real part','Imaginary part');

figure(3)
plot(w,abs(h160),'b',w,real(h160),'y',w,imag(h160),'r');
title('Heave Response Spectrum Mid-Node of Bridge Span');
xlabel('Frequency of motion - [rad/s] ');
ylabel('Vertical displacement - [m] ');
legend('Absolute value','Real part','Imaginary part');


figure(4)
plot(w,abs(h178a),'b',w,real(h178a),'y',w,imag(h178a),'r');
title('Auto-Spectrum Heave Response Mid-Node');
xlabel('Frequency of motion - [rad/s] ');
ylabel('Vertical displacement - [m^2] ');
legend('Absolute value','Real part','Imaginary part');


% Variance of the heave response

varh178 = trapz(w,h178);
varh160 = trapz(w,h160);

% Standard deviation of the heave response

stdh178 = sqrt(varh178);
stdh160 = sqrt(varh160);

% Defining the 0'th, 2'nd and 4'th spectral moments

m0178 = zeros(1,Nw);
m2178 = zeros(1,Nw);
m4178 = zeros(1,Nw);

m0160 = zeros(1,Nw);
m2160 = zeros(1,Nw);
m4160 = zeros(1,Nw);

for i = 1:Nw;
    
    m0178(i) = h178(i);
    m2178(i) = w(i)^2*h178(i);
    m4178(i) = w(i)^2*h178(i);
    
    m0160(i) = h160(i);
    m2160(i) = w(i)^2*h160(i);
    m4160(i) = w(i)^2*h160(i);
    
end

ms0178 = trapz(w,m0178);
ms2178 = trapz(w,m2178);
ms4178 = trapz(w,m4178);

ms0160 = trapz(w,m0160);
ms2160 = trapz(w,m2160);
ms4160 = trapz(w,m4160);

% Determining the rms bandwidth of the process

e178 = sqrt(1 - ((ms2178^2)/(ms0178*ms4178)));
e160 = sqrt(1 - ((ms2160^2)/(ms0160*ms4160)));


% Determining the zero crossing period

Tz178 = 2*pi*sqrt(ms0178/ms2178);
Tz160 = 2*pi*sqrt(ms0160/ms2160);


% Estimation of the largest expected maximum within time intervall T

Ermax178 = stdh178*(sqrt(2*log(T/Tz178)) + 0.5772/(sqrt(2*log(T/Tz178))));
Ermax160 = stdh160*(sqrt(2*log(T/Tz160)) + 0.5772/(sqrt(2*log(T/Tz160))));


% Standard deviation corresponding to the expected largest maximum

stdrmax178 = ((stdh178*pi)/sqrt(6))*(1/(sqrt(2*log(T/Tz178))));
stdrmax160 = ((stdh160*pi)/sqrt(6))*(1/(sqrt(2*log(T/Tz160))));


% Maximum response in heave at mid-node within a desired number of standard
% deviations may be determined. The peak factor, kp, is set at the number
% of standard deviations to include. kp=1 thus corresponds to one standard
% deviation.

rmax178 = abs(Ermax178) + kp*abs(stdrmax178);

rmax160 = abs(Ermax160) + kp*abs(stdrmax160);














