function [SRsway,SRheave,SRroll,w,f] = Bergsoy_Response_sway_heave_roll(a,Hs,Tp)

%
% Development of a one-dimensional response spectra for the sway, heave and
% roll motion as function of frequency.
%
% The frequency response functions at desired nodes are computed and 
% combined with a one-dimensional JONSWAP wave spectrum values at each
% frequency step.
%
% A desired frequency interval is determined with frequency steps, dw. For
% each frequency step, w(i), the dimensionless hydrodynamic coefficients 
% are determined from interpolation functions. The added mass and damping
% coefficients for sway and heave motion are made dimensional by 
% multiplication of rhow*Bp*d and rhow*Bp*d*w(i), respectively. While the 
% added mass and damping coefficents for roll motion are made dimensional
% by multiplication of (rhow*Bp^3*d)/12 and (rhow*Bp^3*d*w(i))/12,
% respectively. Consequently, the draft of the pontoons are predetermined
% in this script to obtain the correct hydrodynamic coefficients.
% 
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Diffraction-radiation of 
% multiple floating structures in directional waves" av S.A. Sannasiraj 
% et.al. These are determined numerically for a 2D rectangular cross
% section with width, B, and is of good compliance with results discovered
% by Markiewicz (1991).
%
% The dimensional hydrodynamic coefficients are then applied to extract the
% proper mass, damping and stiffness matrices associated with frequency
% w(i). These matrices are stored in a matrix array with each matrix being
% og size equal to the global degrees of freedom (ndofG x ndofG), and the
% array being the same size as the number of frequency steps in the loop.
% The property matrices are then added and inverted to form a frequency
% response matrix array. Thus, the matrices stored in the FRF-matrix arrays
% represents the response in all DOF's at that given frequency.
%
% The frequency dependent response spectra for each response parameter are
% obtained by combinating the FRF values at each frequency step and the
% JONSWAP spectrum values at the correponding frequencies.
%
%
%
% Input: myheave      - dimensionless frequency dependent hydrodynamic coefficients
%        mysway
%        myroll
%        lambdaheave
%        lambdasway
%        lambdaroll
%
%        MG,CG,KG     - global property matrices
%
%
% Output: SRsway  - One dimensional response spectrum vector for sway
%                   motion
%         SRheave - One dimensional response spectrum vector for heave
%                   motion
%         SRroll  - One dimensional response spectrum vector for roll
%                   motion
%
%
% Functions: Bergsoy_interpolation_added_mass_heave.m
%            Bergsoy_interpolation_added_mass_sway.m
%            Bergsoy_interpolation_added_mass_roll.m
%            Bergsoy_interpolation_added_mass_surge.m
%            Bergsoy_interpolation_added_mass_pitch.m
%            Bergsoy_interpolation_hydro_damping_heave.m
%            Bergsoy_interpolation_hydro_damping_sway.m
%            Bergsoy_interpolation_hydro_damping_roll.m
%            Bergsoy_interpolation_hydro_damping_surge.m
%            Bergsoy_interpolation_hydro_damping_pitch.m
%            
%
% 
% By Axel Wullf Wathne, 2012.
%
%



% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

L    =  840;      % length of bridge in x-direction  
B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
tds  = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tws  = 0.01;      % thickness of side walls of the superstructure
Nsup = 25;        % number of nodes along the superstructure  


% Properties of the PC-sub system

Lp = 30;        % length of pontoon
Bp = 20;        % width of pontoon in the fluid
hp = 7;         % height of pontoon
td = 0.35;      % thickness of pontoon top and bottom deck
tw = 0.55;      % thickness of pontoon walls
Awp= Lp*Bp;     % water plane area

Lc = 1.20;      % length of connector rod
ry = 1.00;      % outer radius of connector rod, assumed circular      
tc = 0.05;      % thickness of connector rod, assumed circular

Ap = 2*(Bp*td+(hp-(2*td))*tw);  % Area of pontoon cross-section, assumed hollow quadratic section
Ac = 4*pi*(2*ry*tc - tc^2);     % Area of four connector cross-section, assumed hollow circular section   

Asup = (2*(h-tds-ts)*tws)+(B*(tds+ts)); % Area of superstructre cross-section, assumed hollow quadratic section [m2]


denp = 2500;                    % Density of concrete
denS = 7500;                    % Density of steel


g    = 9.81;                    % Gravitational constant
rhow = 1025;                    % Density of salt water


% Evaluation of the draft of a pontoon

% It is assumed that the weight of the overlying structure is equally
% distributed across the pontoons. Such that the weigth on a single pontoon
% is equal to the weight of two superstructure elements, the connector rod
% element and the two pontoon elements.


Lesup = L/(Nsup-1);     % Approximate length of each superstructure element

W  = (2*(Lesup*Asup*denS) + 2*(Lp*Ap*denp) + (Lc*Ac*denS))*g; % Weight distributed to
                                                              % one pontoon from the
                                                              % above structure.

kB = rhow*g*Bp*Lp;       % Buoyancy stiffness 
                                                            
d  = W/kB;               % Draft of the pontoon  



% Degrees of freedom

ndofsup =  150;
ndofpc  =   36;
ndofG   =  360;
npc     =    7;

% Define matrices of size equal to the degrees of freedom of the system
% These matrices must match the number of DOF's of the system after the
% boundary conditions are introduced and the system DOF's reduced.

ndofres  = 7;               % Number of restrained DOF's
ndofGred = ndofG - ndofres; % Reduced number of DOF's for the global system

 
% Define the frequency step for the FRF

dw = 0.05;          % Frequency step
wmax = 5;           % Maximum value of the angular frequency
Nw = fix(wmax/dw);  % Fix to make sure Nw is without decimals

 
% Writing frequency step vector, w, and vectors for the FRF values 

w         = (1:Nw)*dw;
f         = w./(2*pi);
FRFsway1  = zeros(Nw,1);
FRFsway2  = zeros(Nw,1);
FRFheave1 = zeros(Nw,1);
FRFheave2 = zeros(Nw,1);
FRFroll1  = zeros(Nw,1);
FRFroll2  = zeros(Nw,1);
SRsway    = zeros(Nw,1);
SRheave   = zeros(Nw,1);
SRroll    = zeros(Nw,1);



% Writing matrix arrays for storing the property matrices of the system for 
% each frequency step

D1 = zeros(ndofGred,ndofGred,length(w));
D2 = zeros(ndofGred,ndofGred,length(w));
H1 = zeros(ndofGred,ndofGred,length(w));
H2 = zeros(ndofGred,ndofGred,length(w));


% Extracting the frequency dependent hydrodynamic coefficients as vectors
% according to the input frequency vector, w.

% Determine frequency dependent hydrodynamic mass in heave motion
    
     [myheave] = Bergsoy_interpolation_added_mass_heave(w,Bp,g);
     
     
% Determine frequency dependent hydrdynamic mass in sway motion

     [mysway] = Bergsoy_interpolation_added_mass_sway(w,Bp,g);
     
     
% Determine frequency dependent hydrodynamic mass in roll motion
    
     [myroll] = Bergsoy_interpolation_added_mass_roll(w,Bp,g);  
     
     
% Determine frequency dependent hydrodynamic mass in surge motion 
    
     [mysurge] = Bergsoy_interpolation_added_mass_surge(w,Lp,g);  
     
    
% Determine frequency dependent hydrodynamic mass in pitch motion 
    
    [mypitch] = Bergsoy_interpolation_added_mass_pitch(w,Lp,g); 
    
    
    
% Determine frequency dependent hydrodynamic damping in heave motion
   
    [lambdaheave] = Bergsoy_interpolation_hydro_damping_heave(w,Bp,g); 
    

% Determine frequency dependent hydrodynamic damping in sway motion

    [lambdasway] = Bergsoy_interpolation_hydro_damping_sway(w,Bp,g);
    
    
% Determine frequency dependent hydrodynamic damping in roll motion
    
    [lambdaroll] = Bergsoy_interpolation_hydro_damping_roll(w,Bp,g); 
    
    
% Determine frequency dependent hydrodynamic damping in surge motion

   [lambdasurge] = Bergsoy_interpolation_hydro_damping_surge(w,Lp,g);
   
   
% Determine frequency dependent hydrodynamic damping in pitch motion     
   
   [lambdapitch] = Bergsoy_interpolation_hydro_damping_pitch(w,Lp,g);
    

   
for i = 1:Nw;
        
    % Importing frequency dependent JONSWAP spectrum value corresponding to
    % frequency f(i).

    [Sf] = JONSWAP_spectrum_Hz(Hs,Tp,f(i));
    
    
     
     mheave(i) = rhow*Awp*myheave(i);              % Determine mheave input
     
    
     
     msway(i) = rhow*Awp*mysway(i);                % Determine msway input 
     
    
     
     mroll(i) = ((rhow*Bp^3*d)/12)*myroll(i);      % Determine mroll input
     
    
    
     msurge(i) = rhow*Awp*mysurge(i);             % Determine msurge input
     
    
     
     mpitch(i) = ((rhow*Lp^3*d)/12)*mypitch(i);    % Determine mpitch input
     
     
           
   
    
    cheave(i) = rhow*Awp*w(i)*lambdaheave(i);           % Determine cheave input
        
    
    csway(i)  = rhow*Awp*w(i)*lambdasway(i);            % Determine csway input
        
    
    croll(i)  = ((rhow*Bp^3*d)/12)*w(i)*lambdaroll(i);  % Determine croll input
    
  
    csurge(i) = rhow*Awp*w(i)*lambdasurge(i);           % Determine csurge input
   
    
    cpitch(i) = ((rhow*Lp^3*d)/12)*w(i)*lambdapitch(i); % Determine cpitch input
    
    
         
   % Importing the global mass, damping and stiffness matrices for the 
   % global 3D floating bridge model associated with frequency w(i).
    
    [MG,CG,KG] = Bergsoy_G_global_property_matrices(ndofsup,ndofpc,ndofG,npc,msway(i),mheave(i),mroll(i),csway(i),cheave(i),croll(i),msurge(i),mpitch(i),csurge(i),cpitch(i));
   
    
    
   % Introducing boundary conditions of a simply supported bridge construction
   % with additional restraints on the torsional DOF's at each end.
   
   k = [1 2 3 4 146 147 148]; % Restraining global DOF's 1,2,3,4,146,147 & 148.

   MGred = MG;
   CGred = CG;
   KGred = KG;

   MGred(k,:,:) = [];
   MGred(:,k,:) = [];

   CGred(k,:,:) = [];
   CGred(:,k,:) = [];

   KGred(k,:,:) = [];
   KGred(:,k,:) = [];
    
   % Invers of the FRF for frequency w(i) including the hydrodynamic damping.
   
    D1(:,:,i) = (KGred - (w(i)^2)*MGred + sqrt(-1)*w(i)*CGred);
    
    
   % Invers of the FRF for frequency w(i) excluding the hydrodynamic damping.
   
    D2(:,:,i) = (KGred - (w(i)^2)*MGred);
    
 
   % Determination of the FRF's as the inverse of D1 and D2.
   
   % For each frequency step w(i) a matrix D and its inverse H is produced.
   % This matrix, H, represents the response of the system for all DOF's at
   % frequency equal to w(i). To construct a frequency response function
   % for a single response parameter over a range of frequencies, the
   % response value of that response parameter is to be extracted for each
   % frequency step. This is done by extracting abs(H(n,n,i)) for response
   % variable associated with DOF number n, and storing this value in the
   % FRFw vector. At each frequency step, such a value is stored in the
   % FRFW vector, which is finally ploted against the frequency steps.
    
    H1(:,:,i) = inv(D1(:,:,i));      % Writing inverse of D-matrices to obtain
    H2(:,:,i) = inv(D2(:,:,i));      % the FRF-matrices of the damped and undamped
                                     % system responses.
    
    
    % FRF sway motion
    FRFsway1(i)  = abs(H1(74,74,i)); % add in the frequency dependent H1-values
                                     % For horizontal damped response in the center of
                                     % the bridge, D(74), for damped system.
    
                                       
    FRFsway2(i)  = abs(H2(74,74,i)); % add in the frquency dependent H2-values 
                                     % for horizontal undamped response in the center of 
                                     % the bridge, D(74), for undamped system.
                                  
    
                                  
    % FRF heave motion
    FRFheave1(i)  = abs(H1(75,75,i)); % add in the frequency dependent H1-values
                                      % For vertical damped response in the center of
                                      % the bridge, D(75), for damped system.
    
                                          
    FRFheave2(i)  = abs(H2(75,75,i)); % add in the frquency dependent H2-values 
                                      % for vertical undamped response in the center of 
                                      % the bridge, D(75), for undamped system.
    
                                      
                                      
    % FRF roll motion
    FRFroll1(i)  = abs(H1(76,76,i));  % add in the frequency dependent H1-values
                                      % For torsional damped response in the center of
                                      % the bridge, D(76), for damped system.
    
                                        
    FRFroll2(i)  = abs(H2(76,76,i));  % add in the frquency dependent H2-values
                                      % for vertical undamped response in the center of 
                                      % the bridge, D(76), for undamped system.
    
                                      
    % Development of the response spectra vectors
    
    % Response spectrum for sway motion
    
    SRsway(i) = (FRFsway1(i)/a)^2 * Sf;
    
    
    % Response spectrum for heave motion
    
    SRheave(i) = (FRFheave1(i)/a)^2 * Sf;
    
    
    % Response spectrum for sway motion
    
    SRroll(i) = (FRFroll1(i)/a)^2 * Sf;
                                     
    
    
end
 
