function [Wamp,swayamp,surgeamp,rollamp] = Bergsoy_Spatial_amplifyer(wh,Nw,om0)

%
% Spatial wave amplifyer - vector array
%
% Function for determining the link between the surface elevation at 
% different points in space for single sinusoidal waves of angular  
% frequency w. 
% 
% Long-crested waves are assumed to approach a floating bridge from a given
% wave angle of approach, om0. From a spatial description of the wave
% surface elevation the surface elevation at points of interest in the
% xy-plane is obtained. These values are though to scale the frequency
% dependent load amplitudes at each frequency step of a response analysis.
%
% In addition, a second vector array, Wamp2, is produced which contains the
% spatial amplifyer in every point of interest developed by integration of
% the wave surface elevation over the wave angle of approach domain.
%
%
% Input:  dw - frequency step
%       wmax - maximum frequency value in the domain
%         Nw - number of frequency steps
%        om0 - mean direction of wave approach
%          s - spreading index of the spreading function
%
%
% Nodal positioins in space (xy-plane) when the end points of the arch
% shaped bridge span defines the position of the x-axis. At this postion
% the surface elevation is equal to the mean surface elevation, so that the
% wave profile is zero and no force is transmitted to the floating bridge
% at position x=0, y=0.



% Defining the arch shape as function of the x-position of each node.

R    = 1300;   % Radius of the horizontal arch.
Nsup = 25;     % Nodes along the bridge span.
L    = 840;    % Length of bridge in x-direction

% Arch height at mid-point, deltamid.

hmid     = sqrt(R^2 - (L/2)^2);
deltamid = R - hmid;

% Vectors for the x- and y-postion of the nodes along the bridge
% superstructure.

x = (-L/2: L/(Nsup-1) : L/2);

y = zeros(1,length(x));

deltay = zeros(1,length(x));


% Postion of each node in the y-plane corresponding with x-position

for i = 1:length(x);

y(i) = sqrt(R^2 - x(i)^2);    % Function for a circle, defining the y-position 
                              % according to x-postion.
                        
deltay(i) = y(i) - hmid;      % The postion above the x-axis in the y-direction 
                              % of node i along the bridge span.

end

% Defining the positions of connection points between the arch bridge span 
% and the pontoons in space.

xpos = [x(4) x(7) x(10) x(13) x(16) x(19) x(22)];
ypos = [deltay(4) deltay(7) deltay(10) deltay(13) deltay(16) deltay(19) deltay(22)];


s   = 5;        % Spreading index
g   = 9.81;     % Gravitational contant
nom = 0.01;     % Angular step size
a   = 1;        % Wave amplitude


% Wave angle of approach domain

Om = (-pi/2)+om0 : pi*nom : (pi/2)+om0;


% Vectors for storing the angular frequency at each step, the spatial wave 
% amplifyer values for each considered point along the bridge span at each
% frequency step, and for storing the wave numbers.


Wamp  = zeros(1,length(xpos),Nw);
Wamp2 = zeros(1,length(xpos),Nw);
Wom   = zeros(1,length(Om));
k     = zeros(1,Nw);


for t = 1:Nw;
    
    w(t) = wh(t);

% Wave number

k(t) = (w(t)^2)/g;


for i = 1:length(xpos);     % Loop over each position in space
    
    
    %WY  = (cos(Om - om0)).^(2*s).*a.*sin(-k(t).*((x(i).*sin(Om))+(y(i).*cos(Om))));
    
    Wamp(:,i,t) = a*sin(-k(t)*((xpos(i)*sin(om0))+(ypos(i)*cos(om0))));
    
%     for j = 1:length(Om);   % Loop over the angle of appraoch domain to determine
%                             % the wave amplifyer value at each angular
%                             % step.
%     
%     
%     
%     Wom(j) = ((cos(Om(j)-om0)^(2*s))*a*sin(-k(t)*((x(i)*sin(Om(j)))+(y(i)*cos(Om(j))))));
%     
%     end
    
    % For inclusion of a spreading index over the angle of wave approach
    % domain an integration over the angle domain may be carried out to
    % determine the total contribution from the wave field in a point in
    % space.
     
    for p = 1:length(Om)-1;
        
        Wamp2(1,i,t) = Wamp2(1,i,t) + ((Wom(p)+Wom(p+1))/2)*(pi*nom);
        
    end
    
    
end   
    
end

% Determination of the angle of orientation of each pontoon relative to the
% global y-axis which is associated with the omega = 0 angle of incomming
% waves.


% Defining the orientation of each element in space (dx, dy and Le)

dx = L/(Nsup-1);        % Lenght of each element in the x-direction.
dy = zeros(Nsup-1,1);   % Vector for the dy lengths of the elements.
Le = zeros(Nsup-1,1);   % Vector for the total lengths of the elements.
xx = zeros(Nsup-1,1);   % Vector for storing element angles


for i = 1:Nsup-1;       % Loop over the arch elements

dy(i) = deltay(i+1) - deltay(i);      % Length of element i in y-direction.

Le(i) = sqrt(dx*dx + dy(i)*dy(i));    % Total length of element i.


xx(i) = atan(dy(i)/dx);

end

% Vector for the average angle of the arch at the positions of pontoon
% connection relative to the x-axis. These angles are identical to the
% pontoon local x-axis relative to the global y-axis.


xxavg = [xx(3)+xx(4) xx(6)+xx(7) xx(9)+xx(10) xx(12)+xx(13) xx(15)+xx(16) xx(18)+xx(19) xx(21)+xx(22)]*0.5;    

Wavedir = ones(1,length(xxavg))*om0;

% Determining the absolute relative angle, omrel, between the orientation 
% of the pontoons and the oncomming wave direction. 

omrel = abs(xxavg - Wavedir);

% Determining the amount of wave loading being transferred to the pontoon
% elements from the oncoming wave as function of the pontoon orientations
% and the wave approach angle.

swayamp  = zeros(length(xxavg),1);
surgeamp = zeros(length(xxavg),1);
rollamp  = zeros(length(xxavg),1);

for i = 1:length(xxavg);

swayamp(i)  = sin(omrel(i));
surgeamp(i) = cos(omrel(i));
rollamp(i)  = swayamp(i);

end


end


