%function [F] = Bergsoy_hydrodynamic_transfer_function(s,dw,Nw)

%
% Hydrodynamic transfer function F(ndofG,ndofG,Nw)
%
% The aim is to develope a hydrodynamic transfer function for the elements
% of a floating bridge being in contact with the water. Developed for a 3D
% floating bridge model with Nsup = 25 nodes along the superstructure and
% with npc = 7 pontoons introduced which are modelled with four
% hydro-elastic elements and one connnector element. The elements are
% interpolated consistent with the floating bridge model elements. 4DOF's
% describes the displacement of the elements in the vertical & horizontal
% directions. While linear interpolation functions are used for surge and
% roll directions.
%
% The hydrodynamic transfer function may be employed to determine the
% coherence spectrum of the wave loading as function of position in space.
%
% CohQrQs(w) = abs(Frs(w))^2 / Frr(w)*Fss(w)
%
% It is of interest to develope two hydrodynamic transfer functions, for
% two different values of the spreading index, s. One representing a 
% long-crested swell sea state and the other a short-crested sea state.
% Each of these hydrodynamic transfer functions are in turn combined with
% proper JONSWAP spectra, corresponding to the spreading index values, when
% determining the response spectra. The two resulting respons spectra are
% eventually added to form a complete response spectra for sea loading from
% the two sea states. Consequently, the spreading index, s, is an input
% variable in the function.
%
% Input: Nw - number of frequency steps
%        dw - angular frequency step size
%         n - direction angle step size
%         s - spreading index
%    omega0 - mean direction of wave approach
%     ndofG - number of global DOF's
%
%
%
% By Axel Wullf Wathne, 2012.
%

s=5;
dw=0.5;
wmax=3;
Nw=fix(wmax/dw);

% Properties of the PC-sub system

Lp = 30;          % length of pontoon
Bp = 20;          % width of pontoon in the fluid

g    = 9.81;                    % Gravitational constant


ndofG  = 360;  % number of global DOF's
ndofel = 12;   % number of element DOF's 
               % consistent interpolation functions
Nel    = 28;   % number of elements in contact with the fluid
Lep    = Lp/4; % length of elements modelling the pontoons
npc    = 7;    % number of pontoons



% Establishing the orientation in space for the four sub-systems

% Defining the arch shape as function of the x-position of each node.

R    = 1300;   % Radius of the horizontal arch.
Nsup = 25;     % Nodes along the bridge span.
L    = 840;    % Length of bridge in x-direction

% Arch height at mid-point, deltamid.

hmid     = sqrt(R^2 - (L/2)^2);
deltamid = R - hmid;

% Vectors for the x- and y-postion of the nodes along the bridge
% superstructure.

x = (-L/2: L/(Nsup-1) : L/2);

y = zeros(1,length(x));

deltay = zeros(1,length(x));


% Postion of each node in the y-plane corresponding with x-position

for i = 1:length(x);

y(i) = sqrt(R^2 - x(i)^2);    % Function for a circle, defining the y-position 
                              % according to x-postion.
                        
deltay(i) = y(i) - hmid;      % The postion above the x-axis in the y-direction 
                              % of node i along the bridge span.

end


% Defining the positions of connection points between the arch bridge span
% and the pontoons in space.

xpos = [x(4) x(7) x(10) x(13) x(16) x(19) x(22)];
ypos = [deltay(4) deltay(7) deltay(10) deltay(13) deltay(16) deltay(19) deltay(22)];


% Defining the orientation of each element in space (dx, dy and Le)

dx = L/(Nsup-1);        % Lenght of each element in the x-direction.
dy = zeros(Nsup-1,1);   % Vector for the dy lengths of the elements.
Le = zeros(Nsup-1,1);   % Vector for the total lengths of the elements.


for i = 1:Nsup-1;       % Loop over the arch elements

dy(i) = deltay(i+1) - deltay(i);      % Length of element i in y-direction.

Le(i) = sqrt(dx*dx + dy(i)*dy(i));    % Total length of element i.


end


% Vector for the angles at the mid-node of the pontoon sub-systems relative
% to the global x-axis

xx=zeros(7,1);

% Inserting the respective angles
xx(1) = ((atan(dy(3)/dx))  + (atan(dy(4)/dx)))*0.5;
xx(2) = ((atan(dy(6)/dx))  + (atan(dy(7)/dx)))*0.5;
xx(3) = ((atan(dy(9)/dx))  + (atan(dy(10)/dx)))*0.5;
xx(4) = ((atan(dy(12)/dx)) + (atan(dy(13)/dx)))*0.5;
xx(5) = ((atan(dy(15)/dx)) + (atan(dy(16)/dx)))*0.5;
xx(6) = ((atan(dy(18)/dx)) + (atan(dy(19)/dx)))*0.5;
xx(7) = ((atan(dy(21)/dx)) + (atan(dy(22)/dx)))*0.5;

angle = zeros(1,Nel);

for i = 0:npc-1;  % Loop over the pontoons to apply the orientation of the
                  % pontoons to the elements making up the pontoon.
    
angle(1+4*i) = xx(i+1);
angle(2+4*i) = xx(i+1);
angle(3+4*i) = xx(i+1);
angle(4+4*i) = xx(i+1);

end


% Postion in space of the first node of the elements in contact with the
% water as xe and ye vectors.

xe = zeros(1,Nel);
ye = zeros(1,Nel);

% Defining the x-y-position of the elements that has their first nodes at
% the point of connection between the arch and pontoons.
xe(3)  = xpos(1);
xe(7)  = xpos(2);
xe(11) = xpos(3);
xe(15) = xpos(4);
xe(19) = xpos(5);
xe(23) = xpos(6);
xe(27) = xpos(7);

ye(3)  = ypos(1);
ye(7)  = ypos(2);
ye(11) = ypos(3);
ye(15) = ypos(4);
ye(19) = ypos(5);
ye(23) = ypos(6);
ye(27) = ypos(7);

for i = 0:npc-1; % Looping the pontoons to determine the x-y-position of 
                 % remaining elements of each pontoon.

xe(1+4*i) = xe(3+4*i) + 2*Lep*sin(xx(1+i));
xe(2+4*i) = xe(3+4*i) +   Lep*sin(xx(1+i));
xe(4+4*i) = xe(3+4*i) -   Lep*sin(xx(1+i));

ye(1+4*i) = ye(3+4*i) - 2*Lep*cos(xx(1+i));
ye(2+4*i) = ye(3+4*i) -   Lep*cos(xx(1+i));
ye(4+4*i) = ye(3+4*i) +   Lep*cos(xx(1+i));

end


% Writing a matrix to store the individual x & y position differences
% between pontoon elements m & n. 

X = zeros(Nel);
Y = zeros(Nel);

for m = 1:Nel;      % Loop over the pontoon elements
    for n = m:Nel;
        
        X(m,n) = abs(xe(m) - xe(n));
        Y(m,n) = abs(ye(m) - ye(n));
        
    end
end


% Defining the wave directional angle range and step size

nom = 0.1;         % angluar step size
omega0 = 0;         % mean direction of wave approach

Omega = omega0-(pi/2) : (nom*pi) : omega0+(pi/2);


% Importing the scaling factor, Ns, for the spreading function according to
% the spreading index, s.

[Direc, Ns, SumDirec] = cos_directional_spreading_function(nom,omega0,s);

figure(1);
plot(Omega,Direc);
title(['Spreading function for spreading index,  s = ',num2str(s),'']);
xlabel('Wave angle of approach - radians');


% All matrices developed in this script are evaluated as functions of
% frequency. Consequently, a loop over the frequency domain is started.

% Alpha 4D-matrix for storing the exponential terms relating the spatial
% distributions of elements m & n for wave angular step Omega(j) and
% frequency step w(i). alpha = [m,n,j,i]

alpha = zeros(Nel,Nel,length(Omega),Nw);


% Omeg matrix array. Each matrix developed at frequency step w(i). The
% terms in the Omeg matrix at w(i) corresponds to the integral of the alpha
% matrix terms at w(i) over the wave angle of approach domain.

Omeg = zeros(Nel,Nel,Nw);


% Vectors for storing the values of the spreading function at each wave
% angle step and the corresponding product of the spreading function values
% and the alpha values at each frequency step.

waveintegral = zeros(1,length(Omega));

waveintalpha = zeros(Nel,Nel,length(Omega));


% Matrix for storing the hydrodynamic transfer function values in heave for
% combined elements m & n.
% The matrix associated with combined elements m&n for frequency step w(i)
% have dimensions equal to the DOF's of the element, 12x12.

Fmn = zeros(12,12,Nel,Nel,Nw);

% Matrix array for storing the hydrodynamic transfer functions as matrices 
% at each frequency step w(i).
% The hydrodynamic tranfer function matrices have dimensions [360x360] from 
% the number of global DOF's being 360.

F = zeros(ndofG,ndofG,Nw);

w = zeros(1,Nw);

for i = 1:Nw;
    
    
    w(i) = i*dw;    % Frequency step for determining the hydro matrices
    
    
    
    % Importing the frequency dependent load transfer function for the
    % heave motion of a pontoon, q(w(i))
    
    [q0h,q0hdim,wdim] = floating_bridge_3D_load_amplitude_heave(Bp,w(i));
    
    
    % Importing a load matrix for the wave loading in heave on a single
    % element modelled with 4DOF's in verical direction.
    
    [Qloadheave] = Bergsoy_wave_load_matrix_heave(Lep);
    
    
    % Defining a frequency dependent load load vector for allocation of a
    % distributed load over elements m and n of equal length, Lep.
    % (Scaled properly by dividing by Lep^2 ????)
    
    Qhmn = (q0h^2)*Qloadheave;
                           
      
    % Defining a wave-angle-of-approach-domain.
    
    for j=1:length(Omega);  
        
            Om = Omega(j);
            
            
    % Writing the value of the spreading function for each angular step
    
    waveintegral(j) = Ns*(cos(Om-omega0))^(2*s);
    
                  
    % Defining the upper right part of a [NelxNel]-matrix containing the 
    % alpha-values associated with frequency w(i) and wave angle of
    % approach Omega(j) = Om. The values are generally complex.
    
    
    for m = 1:Nel;
        for n = m:Nel;
            
            if m==n;
                
                alpha(m,n,j,i) = 1+sqrt(-1)*0;  % Diagonal terms equal 1 Real
                                                % and zero for Imaginary.
                                                
            else
                
                alpha(m,n,j,i) = 1*exp(sqrt(-1)*abs(w(i))*(w(i)/g)*(Y(m,n)*cos(Om) + X(m,n)*sin(Om)));
                
            end
            
                waveintalpha(m,n,j) = waveintegral(j)*alpha(m,n,j,i);
            
         end
    end 
    
    
    end
    
    % The alpha matrices are developed over the wave approach angle domain
    % for frequency step w(i). The integral of the alpha-matrix array
    % corresponding to frequency step w(i) is taken over the wave angle
    % domain for each of the terms in the matrix.
    
    
    for j = 1:length(Omega);
        
        for m = 1:Nel;
            for n = m:Nel;
            
            if m==n;
                
                Omeg(m,n,i) = 1;  % Integrated to unity for diagonal terms
                
            else
                
                
                
                Omeg(m,n,i) = trapz(Omega,waveintalpha(m,n,:));
                
            end
            end
        end
    end
    
    
    % Computing the load spectrum matrix associated with frequency step
    % w(i) by introducing the JONSWAP value associated with w(i) and the
    % spatial scaling function Omeg(m,n,w(i)) for w(i) and elements m & n.
    % These quantities are applied to the heave loading on an element,
    % Qhmn.
    
    for m = 1:Nel;
        for n = m:Nel;
            
    Fmn(:,:,m,n,i) = Qhmn.*Omeg(m,n,i);
    
    Fmn(:,:,n,m,i) = Fmn(:,:,m,n,i);
    
        end
    end
    
    % The SQmn matrices are [12x12] matrices linking the wave loading on
    % elements m&n. The diagonal matrices m=n express the wave loading on
    % each of the elements (autospectrum), while the off-diagonal terms
    % express the correlated wave loading on elements m-n.
    
    % The element wave loading spectrums are allocated into a matrix of
    % size equal to the global DOF's to form a wave loading spectrum for
    % the full model at each frequency step, w(i).
    
    % Importing connectivity matrices linking the pontoon element DOF's to
    % the global DOF's.
    
    [ahydro] = Bergsoy_connectivity_hydro_transfer(ndofel,Nel,npc,ndofG);
    
    
    % The connectivity matrices are employed within the frequency step w(i)
    % to determine the wave load spectrum matrix [360x360] associated with
    % frequency w(i).
    
    for m = 1:Nel;
        for n = m:Nel;
    
    F(:,:,i) = F(:,:,i) + (ahydro(:,:,m)')*Fmn(:,:,m,n,i)*ahydro(:,:,n);
    
        end
    end

    
end


% Evaluation of the coherence spectrum for the wave loading 

CohQrQs = zeros(ndofG,ndofG,Nw);


for i=1:Nw;
for r = 1:ndofG;
    for s = r:ndofG;
        
        if r==s;
            
            CohQrQs(r,s,i) = 1;
        else

CohQrQs(r,s,i) = (abs(F(r,s,i)))^2/(F(r,r,i)*F(s,s,i));


CohQrQs(s,r,i) = CohQrQs(r,s,i);
        end
    end
end
end


% Coherence function for the heave loading in the points of the floating
% bridge model being in contact with the surrounding fluid
% The coherence functions are functions of frequency as the spatial
% distribution of the sea surface alter with change in frequency of the
% waves.

ndofQh = 5*npc;     % Number of loaded nodes on the pontoons

Cohheave = zeros(ndofQh,Nw);

% Number of the DOF's associated with heave at the pontoons prior to
% inclusion of the boundary conditions.

nodesm =zeros(npc,5);

for n = 0:npc-1;    % Loop over the pontoon sub-systems
    for k = 0:4;    % Loop over pontoon sub-system nodes

nodesm(n+1,k+1) = 27 + 6*k + 48*n;

    end
end

nodesv = zeros(1,ndofQh);   % Vector for storing the DOF numbers in order

nodesv(1:5)   = nodesm(1,1:5);
nodesv(6:10)  = nodesm(2,1:5);
nodesv(11:15) = nodesm(3,1:5);
nodesv(16:20) = nodesm(4,1:5);
nodesv(21:25) = nodesm(5,1:5);
nodesv(26:30) = nodesm(6,1:5);
nodesv(31:35) = nodesm(7,1:5);


% Determination of choherence vector in heave for mid-node (DOF no.183)

for i = 1:Nw;
    for j = 1:ndofQh

    Cohheave(j,i) = CohQrQs(183,nodesv(j),i);
    
    end
end

% Plot of the coherence bewteen the wave loading in the mid-node of the
% center pontoon and the heave loading in the other pontoon nodes.


x = 1:ndofQh;       % Writing a postion vector 
i = 3;             % Frequency step for extracting the coherence

figure(1)
plot(x,abs(Cohheave(:,i)));
title(['Coherence for the mid-node in the center pontoon for frequency ',num2str(i),]);
ylabel('Coherence in heave wave loading');

figure(2)
surfl(w,x,abs(Cohheave));
title(['Coherence Distribution For Wave Loading at Mid-Point for s = ',num2str(s),]);




%end
    
    
    
    
    
    
    
    
    
    
    
