function [mzz,Mzz] = Bergsoy_interpolation_added_mass_heave(w,Bp,g,d)


% Interpolation function to determine the dimensionless hydrodynamic
% added mass assosiated with vertical, heave, motion of a rectangular
% structure.
%
% The values for the hydrodynamic added mass coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w*sqrt(B/2*g). The other containing the corresponding values for
% the dimensionless added mass in heave motion.
%
% The dimensionless hydrodynamic mass in heave is made dimensionless by the
% division mzz/(rhow*Awp).
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Frequency domain analysis
% of a foating bridge exposed to irregular short-crested waves" by Langen.
% The values are derived from Vugts, J.H. "The hydrodynamic coefficients 
% for swaying, heaving and rolling cylinders in a free surface".
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%       wnorm = Vector of dimensionless angular frequency
%    mzvalues = Vector of hydrodynamic added mass coefficients for heave motion
%         mzz = Output dimensionless hydrodynamic added mass coefficents for
%               heave motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.
%



rhow = 1025;

mzz = zeros(1,length(w));

Mzz = zeros(1,length(w));


for k=1:length(w);
    

    w1normi(k) = abs(w(k)*sqrt(Bp/(2*g)));  %Normalised absolute value of
                                            % angular frequency input

if  w1normi(k) > 2.0;
    
        mzz(k) = 2.00;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
mzvalues  =  [10.0 5.0 3.20 2.40 1.95 1.70 1.45 1.40 1.45 1.55 1.65 1.70 1.75 1.85 1.90 1.95 2.00];


mzz(k) = interp1(wnorm,mzvalues,w1normi(k),'spline');


end

% Added mass per unit length along pontoon element [kg/m]

Mzz(k) = rhow*Bp*d*mzz(k);    

end

% figure(1);
% plot(wnorm,mzvalues);
% title('Dimensionless Added Mass - Heave');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - Mzz/(rhow*Bp*d');
% 
% figure(2);
% plot(w,Mzz);
% title('Added Mass - Heave');
% xlabel('Frequency - (rad/s)');
% ylabel('Added mass per unit lenght - Mzz [kg/m]');


end
