function [mypitch] = Bergsoy_interpolation_added_mass_pitch(w,Lp,g)

% Interpolation function to determine the dimensionless hydrodynamic
% added mass assosiated with the roll motion of a rectangular structure.
% This script is intended for the longitudinal direction of the pontoons,
% thus the pitch motion. However, the hydrodynamic roll coefficients are
% applied with the length of the pontoon being introduced instead of the
% width of the pontoons.
%
% The values for the hydrodynamic added mass coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w^2*B/2*g. The other containing the corresponding values for
% the dimensionless added mass in roll motion.
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Diffraction-radiation of 
% multiple floating structures in directional waves" av S.A. Sannasiraj 
% et.al. These are determined numerically for a 2D rectangular cross
% section with width, B, and is of good compliance with results discovered
% by Markiewicz (1991).
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%       wnorm = Vector of dimensionless angular frequency
%        my55 = Vector of hydrodynamic added mass coefficients for roll motion
%      myroll = Output dimensionless hydrodynamic added mass coefficents for
%               roll motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.




mypitch = zeros(1,length(w));

for k=1:length(w);
    

    w1normi(k) = (w(k)^2*Lp)/(2*g);    %Normalised angular frequency input

if w1normi(k)<0 
        disp(['Angular frequency ',num2str(w(k)),' w is too low']);
    elseif w1normi(k)>2.5
        mypitch(k) = 1.25;
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.25 0.50 0.75 0.88 1.00 1.10 1.25 1.50 1.75 2.00 2.25 2.50]; 
                                                                  
my55  = [1.55 1.58 1.67 1.88 2.13 1.20 0.55 0.95 1.05 1.12 1.15 1.20 1.22];


mypitch(k) = interp1(wnorm,my55,w1normi(k),'spline');

end

end

end
