function [mrr,Mrr] = Bergsoy_interpolation_added_mass_roll(w,Bp,g,d)


% Interpolation function to determine the dimensionless hydrodynamic
% added mass assosiated with the roll motion of a rectangular structure.
%
% The values for the hydrodynamic added mass coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w*sqrt(B/2*g). The other containing the corresponding values for
% the dimensionless added mass in heave motion.
%
% The dimensionless hydrodynamic mass in roll is made dimensionless by the
% division mrr/(rhow*Awp*Bp^2).
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Frequency domain analysis
% of a foating bridge exposed to irregular short-crested waves" by Langen.
% The values are derived from Vugts, J.H. "The hydrodynamic coefficients 
% for swaying, heaving and rolling cylinders in a free surface".
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%       wnorm = Vector of dimensionless angular frequency
%   mrrvalues = Vector of hydrodynamic added mass coefficients for heave motion
%         mrr = Output dimensionless hydrodynamic added mass coefficents for
%               roll motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.



rhow = 1025;

mrr = zeros(1,length(w));
Mrr = zeros(1,length(w));



for k=1:length(w);
    

    w1normi(k) = abs(w(k)*sqrt(Bp/(2*g)));  %Normalised absolute value of
                                            % angular frequency input

if  w1normi(k) > 2.0;
    
        mrr(k) = 0.45;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = 0:0.125:2; 

mrrmax = 0.7;
mrrmin = 0.5;

mrrvalues  =  zeros(1,length(wnorm));

for i = 0:length(wnorm)-1;

mrrvalues(i+1)= mrrmax - i*((mrrmax-mrrmin)/length(wnorm));

end

mrr(k) = interp1(wnorm,mrrvalues,w1normi(k),'spline');

end

% Added mass per unit length along pontoon element [kg/m]

Mrr(k) = rhow*Bp^3*d*mrr(k);    

end

% figure(1);
% plot(wnorm,mrrvalues);
% title('Dimensionless Added Mass - Roll');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - Mrr/(rhow*Awp*Bp');
% 
% figure(2);
% plot(w,Mrr);
% title('Added Mass - Roll');
% xlabel('Frequency - (rad/s)');
% ylabel('Added mass per unit lenght - Mrr [kg/m]');


end
