function [mxx,Mxx] = Bergsoy_interpolation_added_mass_surge(w,Lp,g,d)

% Interpolation function to determine the dimensionless hydrodynamic
% added mass associated with horizontal, surge, motion of a pontoon in the
% longitudinal direction. The hydrodynamic sway coefficients are applied
% with the length of the pontoons introduced instead of the pontoon width.
% Thus the the determined dimensional added mass in surge, Mxx, is added
% mass per unit width of the pontoons. This approach seems reasonable due
% to the nearly rectangular shape of the pontoons.
% 
%
% The values for the hydrodynamic added mass coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w^2*B/2*g. The other containing the corresponding values for
% the dimensionless added mass in sway motion.
%
%
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%       wnorm = Vector of dimensionless angular frequency
%    myvalues = Vector of hydrodynamic added mass coefficients for sway motion
%         mxx = Output dimensionless hydrodynamic added mass coefficents for
%               surge motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.
%


rhow = 1025;

mxx = zeros(1,length(w));
Mxx = zeros(1,length(w));


for k=1:length(w);
    

    w1normi(k) = (w(k)^2*Lp)/(2*g);    %Normalised angular frequency input

if w1normi(k)<0 
        disp(['Angular frequency ',num2str(w(k)),' w is too low']);
    elseif w1normi(k)>2.5
        mxx(k) = 0.10;
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
myvalues  =  [0.53 0.535 0.545 0.55 0.57 0.575 0.57 0.55 0.515 0.475 0.25 0.15 0.05 0.025 0.0125 0.00625 0.003];


mxx(k) = interp1(wnorm,myvalues,w1normi(k),'spline');


% Added mass per unit width along pontoon element [kg/m]

Mxx(k) = rhow*Lp*d*mxx(k);   


end

end

end
