function [myy,Myy] = Bergsoy_interpolation_added_mass_sway(w,Bp,g,d)

% Interpolation function to determine the dimensionless hydrodynamic
% added mass assosiated with horisontal, sway, motion of a rectangular
% structure.
%
% The values for the hydrodynamic added mass coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w*sqrt(B/2*g). The other containing the corresponding values for
% the dimensionless added mass in heave motion.
%
% The dimensionless hydrodynamic mass in sway is made dimensionless by the
% division myy/(rhow*Awp).
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Frequency domain analysis
% of a foating bridge exposed to irregular short-crested waves" by Langen.
% The values are derived from Vugts, J.H. "The hydrodynamic coefficients 
% for swaying, heaving and rolling cylinders in a free surface".
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%           d =  draft of the pontoon
%       wnorm = Vector of dimensionless angular frequency
%   myyvalues = Vector of hydrodynamic added mass coefficients for heave motion
%         myy = Output dimensionless hydrodynamic added mass coefficents for
%               heave motion. Calculated for each frequency step, k.
%
%
%
%
% By Axel W. Wathne, 2012.



rhow = 1025;


myy = zeros(1,length(w));
Myy = zeros(1,length(w));


for k=1:length(w);
    

    w1normi(k) = abs(w(k)*sqrt(Bp/(2*g)));  %Normalised absolute value of
                                            % angular frequency input

if  w1normi(k) > 2.0;
    
        myy(k) = 0.001;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
myvalues  =  [0.53 0.535 0.545 0.55 0.57 0.575 0.57 0.55 0.515 0.475 0.25 0.15 0.05 0.025 0.0125 0.00625 0.003];


myy(k) = interp1(wnorm,myvalues,w1normi(k),'spline');

end

% Added mass per unit length along pontoon element [kg/m]

Myy(k) = rhow*Bp*d*myy(k);    

end

% figure(1);
% plot(wnorm,myvalues);
% title('Dimensionless Added Mass - Sway');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - Myy/(rhow*Bp*d');
% 
% figure(2);
% plot(w,Myy);
% title('Added Mass - Sway');
% xlabel('Frequency - (rad/s)');
% ylabel('Added mass per unit lenght - Myy [kg/m]');



end

