function [czz,Czz] = Bergsoy_interpolation_hydro_damping_heave(w,Bp,g,d)


% Interpolation function to determine the dimensionless hydrodynamic
% damping assosiated with vertical, heave, motion of a rectangular
% structure.
%
% The values for the hydrodynamic damping coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w*sqrt(B/2*g). The other containing the corresponding values for
% the dimensionless added mass in heave motion.
%
% The dimensionless hydrodynamic damping in heave is made dimensionless by 
% the division (czz/(rhow*Awp))*sqrt(B/2*g).
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Frequency domain analysis
% of a foating bridge exposed to irregular short-crested waves" by Langen.
% The values are derived from Vugts, J.H. "The hydrodynamic coefficients 
% for swaying, heaving and rolling cylinders in a free surface".
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%           d =  draft of pontoon
%       wnorm = Vector of dimensionless angular frequency
%    czvalues = Vector of hydrodynamic added mass coefficients for heave motion
%         czz = Output dimensionless hydrodynamic damping coefficents for
%               heave motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.
%



rhow = 1025;

czz = zeros(1,length(w));
Czz = zeros(1,length(w));

for k=1:length(w);
    

    w1normi(k) = abs(w(k)*sqrt(Bp/(2*g)));  %Normalised absolute value of
                                            % angular frequency input

if  w1normi(k) > 2.0;
    
        czz(k) = 0.00;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
czvalues  =  [0 0.45 0.75 0.925 1.0 0.975 0.85 0.75 0.6 0.45 0.35 0.25 0.175 0.1 0.075 0.05 0];


czz(k) = interp1(wnorm,czvalues,w1normi(k),'spline');

end

Czz(k) = rhow*Bp*d*czz(k)/(sqrt(Bp/(2*g)));

end

% figure(1);
% plot(wnorm,czvalues);
% title('Dimensionless Hydrodynamic Damping - Heave');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - Czz*sqrt(Bp/2g)/(rhow*Bp*d)');
%
% figure(2);
% plot(w,Czz);
% title('Hydrodynamic Damping - Heave');
% xlabel('Frequency - (rad/s)');
% ylabel('Hydrodynamic damping per unit lenght - Czz [N*s/m]');

end
