function [lambdapitch] = Bergsoy_interpolation_hydro_damping_pitch(w,Lp,g)

% Interpolation function to determine the dimensionless hydrodynamic
% damping assosiated with pitch motion of a rectangular structure. The
% hydrodynami roll coefficients are applied, with the length of the
% pontoons introduced instead of the pontoon width.
%
% The values for the hydrodynamic damping coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w^2*B/2*g. The other containing the corresponding values for
% the dimensionless damping in roll motion.
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Diffraction-radiation of 
% multiple floating structures in directional waves" av S.A. Sannasiraj 
% et.al. These are determined numerically for a 2D rectangular cross
% section with width, B, and is of good compliance with results discovered
% by Markiewicz (1991).
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%       wnorm = Vector of dimensionless angular frequency
%    lambda55 = Vector of hydrodynamic damping coefficients for roll motion
% lambdapitch = Output dimensionless hydrodynamic damping coefficents for
%               pitch motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.

lambdapitch = zeros(1,length(w));

for k=1:length(w);
    

    w1normi(k) = (w(k)^2*Lp)/(2*g);    %Normalised angular frequency input

if w1normi(k)<0 
        disp('Angular frequency w1 is too low');
    elseif w1normi(k)>2.5
        lambdapitch(k) = 0.04;
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm  =  [0.00 0.25 0.50 0.75 0.90 1.00 1.25 1.50 1.75 2.00 2.25 2.50]; 
                                                                  
lambda55 = [0.0 0.10 0.13 0.25 1.80 1.75 0.33 0.20 0.13 0.10 0.07 0.05];


lambdapitch(k) = interp1(wnorm,lambda55,w1normi(k),'spline');

end

end

end