function [crr,Crr] = Bergsoy_interpolation_hydro_damping_roll(w,Bp,g,d)


% Interpolation function to determine the dimensionless hydrodynamic
% damping assosiated with roll motion of a rectangular structure.
%
% The values for the hydrodynamic damping coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w*sqrt(B/2*g). The other containing the corresponding values for
% the dimensionless added mass in heave motion.
%
% The dimensionless hydrodynamic damping in roll is made dimensionless by the
% division (crr/(rhow*Awp*Bp^2))sqrt(Bp/2*g).
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Frequency domain analysis
% of a foating bridge exposed to irregular short-crested waves" by Langen.
% The values are derived from Vugts, J.H. "The hydrodynamic coefficients 
% for swaying, heaving and rolling cylinders in a free surface".
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%           d = draft of pontoon
%       wnorm = Vector of dimensionless angular frequency
%   crrvalues = Vector of hydrodynamic damping coefficients for roll motion
%         crr = Output dimensionless hydrodynamic damping coefficents for
%               roll motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.


rhow = 1025;

crr = zeros(1,length(w));
Crr = zeros(1,length(w));


for k=1:length(w);
    

    w1normi(k) = abs(w(k)*sqrt(Bp/(2*g)));  %Normalised absolute value of
                                            % angular frequency input

if  w1normi(k) > 2.0;
    
        crr(k) = 0.0075;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = 0:0.125:2; 

crrmax = 0.007;
crrmin = 0;

crrvalues  =  zeros(1,length(wnorm));

for i = 0:length(wnorm)-1;

crrvalues(i+1)= crrmin + i*((crrmax-crrmin)/length(wnorm));

end

crr(k) = interp1(wnorm,crrvalues,w1normi(k),'spline');

end

Crr(k) = rhow*Bp^3*d*crr(k)/(sqrt(Bp/(2*g)));

end

% figure(1);
% plot(wnorm,crrvalues);
% title('Dimensionless Hydrodynamic Damping - Roll');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - Crr*sqrt(Bp/2g)/(rhow*Bp^3*d)');
% 
% figure(2);
% plot(w,Crr);
% title('Hydrodynamic Damping - Roll');
% xlabel('Frequency - (rad/s)');
% ylabel('Hydrodynamic damping per unit lenght - Crr [Nm^2*s/m]');

end
