function [cyy,Cyy] = Bergsoy_interpolation_hydro_damping_sway(w,Bp,g,d)

% Interpolation function to determine the dimensionless hydrodynamic
% damping assosiated with horisontal, sway, motion of a rectangular
% structure.
%
% The values for the hydrodynamic damping coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w*sqrt(B/2*g). The other containing the corresponding values for
% the dimensionless added mass in heave motion.
%
% The dimensionless hydrodynamic damping in heave is made dimensionless by 
% the division (czz/(rhow*Awp))*sqrt(B/2*g).
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Frequency domain analysis
% of a foating bridge exposed to irregular short-crested waves" by Langen.
% The values are derived from Vugts, J.H. "The hydrodynamic coefficients 
% for swaying, heaving and rolling cylinders in a free surface".
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%       wnorm = Vector of dimensionless angular frequency
%    czvalues = Vector of hydrodynamic added mass coefficients for heave motion
%         cyy = Output dimensionless hydrodynamic damping coefficents for
%               sway motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.
%





rhow = 1025;

cyy = zeros(1,length(w));
Cyy = zeros(1,length(w));


for k=1:length(w);
    

    w1normi(k) = abs(w(k)*sqrt(Bp/(2*g)));  %Normalised absolute value of
                                            % angular frequency input

if  w1normi(k) > 2.0;
    
        cyy(k) = 0.20;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
cyvalues  =  [0 0 0 0.025 0.0875 0.225 0.4 0.5875 0.65 0.6875 0.6375 0.6125 0.5625 0.5 0.4625 0.425 0.35];


cyy(k) = interp1(wnorm,cyvalues,w1normi(k),'spline');

end

Cyy(k) = rhow*Bp*d*cyy(k)/(sqrt(Bp/(2*g)));

end

% figure(1);
% plot(wnorm,cyvalues);
% title('Dimensionless Hydrodynamic Damping - Sway');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - Cyy*sqrt(Bp/2g)/(rhow*Bp*d)');
% 
% figure(2);
% plot(w,Cyy);
% title('Hydrodynamic Damping - Sway');
% xlabel('Frequency - (rad/s)');
% ylabel('Hydrodynamic damping per unit lenght - Cyy [N*s/m]');

end
