function [q0,q0dim,wdim] = Bergsoy_load_amplitude_heave(Bp,d,w)

%
% Function for the load amplitude in heave on a beam element (pontoon)
%
% Input:   B - width of beam element in fluid
%          d - draft of beam element i fluid
%          w - vector of angular frequencies
%
% Output; q0 - vector of load amplitude per unit length [N/m]
%      q0dim - vector of dimensionless load amplitude per unit length
%       wdim - vector of dimensionless angular frequency
%
%
% The load amplitude is calculated per unit length of a floating beam. The
% width, B, of the beam is included in the calculations as well as the
% draft, d, of the floating beam. The load amplitude represents a maximum
% amplitude of a harmonic wave excitation load on a floating body in heave,
% according to the frequency of motion. 
%
% It is seen that as the angular frequency is zero, the dimensionless force
% amplitude is equal to unity, which represents a structura that follows
% the elevation of the sea surface for long-period waves. As the frequency
% increases, the load amplitude decreases as less force is transferred to
% the floating body at higher frequencies. 
%
%
%
% By Axel Wullf Wathne, 2012.
%
%


k     = zeros(length(w),1);  % vector for storing wave numbers
q0    = zeros(length(w),1);  % vector for storing load amplitudes
q0dim = zeros(length(w),1);  % vector for storing dimensionless load amplitude
wdim  = zeros(length(w),1);  % vector for storing dimensionless frequency 

rhow = 1025;                % density of water
g    = 9.81;                % gravitational acceleration

for j = 1:length(w);
        
        
        k(j) = (w(j)^2)/g;    % wave number
        
        q0(j) = rhow*g*(2/k(j))*sin((Bp*k(j))/2)*exp(-k(j)*d);
        
end

q0dim = q0./(rhow*g*Bp);

wdim  = w.*(sqrt(Bp/(2*g)));

end




