%function [Mpc,Cpc,Kpc] = Bergsoy_pc_assembly_local(ndofpc,Myy,Mzz,Mrr,Mxx,Cyy,Czz,Crr,Cxx)

%
% Assembly of the pontoon-connector sub-system in its local coordinate
% system.
%
% The property matrices (mass, damping, stiffness) of the pontoon-connector
% sub-system are assembled from each of the elements by use of connectivity
% matrices. The resulting mass, damping and stiffness matrices apply to the
% local sub-system coordinate system.
%
%
% Functions: Bergsoy_pc_hydroelastic_mass_matrix.m
%            Bergsoy_pc_hydroelastic_damping_matrix.m
%            Bergsoy_pc_hydroelastic_stiffness_matrix.m
%            Bergsoy_pc_connector_structural_mass_matrix.m
%            Bergsoy_pc_connector_structural_stiffness_matrix.m
%            Bergsoy_pc_connectivity_matrices.m
%
%
% By Axel Wullf Wathne, 2012.
%

ndofpc=36;
Myy=1;
Mzz=1;
Mrr=1;
Mxx=1;
Cyy=1;
Czz=1;
Crr=1;
Cxx=1;

% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

Nsup = 25;        % number of nodes of the superstructure
L    = 840;       % total length of bridge in x-direction
B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
td   = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tw   = 0.01;      % thickness of side walls of the superstructure


As = (2*(h-td-ts)*tw)+(B*(td+ts));        % Area of superstructre cross-section, assumed hollow quadratic section [m2]


% Defining the properties of the pontoon-connector sub-system

Lp = 30;        % length of pontoon
Bp = 20;        % width of pontoon in the fluid
hp = 7;         % height of pontoon
td = 0.35;      % thickness of pontoon top and bottom deck
tw = 0.55;      % thickness of pontoon walls

Lc = 1.20;      % length of connector rod
ry = 1.00;      % outer radius of connector rod, assumed circular      
tc = 0.05;      % thickness of connector rod, assumed circular

Npc= 6;         % number of nodal points
dx = Lp/4;      % length of hydroelasti pontoon elements, 4 elements.


Es = 200E9;                     % E-modulus of steel [N/m2]
Ec = 30E9;                      % E-modulus of concrete [N/m2]


nuc = 0.2;                      % Poisson's ratio for high strenght concrete
nus = 0.3;                      % Poisson's ratio for steel



Ap = 2*(Bp*td+(hp-(2*td))*tw);  % Area of pontoon cross-section, assumed hollow quadratic section

Ac = 4*pi*(2*ry*tc - tc^2);     % Area of four connector cross-section, assumed hollow circular section  



% 2nd moment of inertia of the pontoon cross-section about y-y
Iyp  = 2*((Bp*td^3 + tw*(hp-(2*td))^3)/12 + Bp*td*((hp-td)/2)^2);

% 2nd moment of inertia of the pontoon cross-section about z-z
Izp  = 2*((td*Bp^3 + ((hp-(2*td))*tw^3))/12 + (hp-(2*td))*tw*((Bp-tw)/2)^2);  

% 2nd moment of inertia of four connector cross-section, circular
Iyc  = 4*(pi/4)*(ry^4 - (ry-tc)^4);             
Izc  = Iyc;



Jp   = (4*hp^2*Bp^2)/(2*(hp/tw)+2*(Bp/td));     %Torsional moment of inertia for the rectangular hollow pontoon
                                                % cross-section,assuming constant wall thickness,tp                                                                                                                                                                                                                            
Jc   = 4*pi*((2*ry)^4 - (ry-tc)^4);             % Polar moment of inertia for four connector rod cross-section




denc = 2500;                    % Density of concrete
dens = 7500;                    % Density of steel



g    = 9.81;                    % Gravitational constant
rhow = 1025;                    % Density of salt water

ndofel = 12;                    % Number of DOF's for an element


% Evaluation of the draft of a pontoon

% It is assumed that the weight of the overlying structure is equally
% distributed across the pontoons. Such that the weigth on a single pontoon
% is equal to the weight of two superstructure elements, the connector rod
% element and the two pontoon elements.


Lesup = L/(Nsup-1);

W  = (3*(Lesup*As*dens) + (Lp*Ap*denc) + (Lc*Ac*dens))*g; % Weight distributed to
                                                            % one pontoon from the
                                                            % above structure.

kB = rhow*g*Bp*Lp;       % Buoyancy stiffness 
                                                            
d  = W/kB;               % Draft of the pontoon  



% Extracting the property matrices for both pure structural and
% hydroelastic elements.

% Hydroelastic element property matrices associated with the pontoons

[Mehydro,Melong] = Bergsoy_pc_hydroelastic_mass_matrix(denc,Jp,dx,Ap,Bp,hp,Myy,Mzz,Mrr,Mxx);

[Cehydro,Celong] = Bergsoy_pc_hydroelastic_damping_matrix(Jp,dx,Ap,Bp,hp,Cyy,Czz,Crr,Cxx);

[Kehydro] = Bergsoy_pc_hydroelastic_stiffness_matrix(g,d,rhow,Ec,nuc,dx,Ap,Iyp,Izp,Jp,Bp);



% Structural element property matrices, for the connector rod

[Mec] = Bergsoy_pc_connector_structural_mass_matrix(dens,Jc,Lc,Ac);

[Kec] = Bergsoy_pc_connector_structural_stiffness_matrix(Es,nus,Lc,Ac,Iyc,Izc,Jc);


% Extracting the connectivity matrices for the local assembly of the
% pontoon-connector sub-system.

[apc] = Bergsoy_pc_connectivity_matrices(ndofel,ndofpc,Npc);


% Assembly of the pontoon-connector sub-system

Mpc = zeros(ndofpc);  % Sub-system property matrices of dimension  
Cpc = zeros(ndofpc);  % according to the ndofpc=36 being the number of DOF's 
Kpc = zeros(ndofpc);  % for the sub-system.


for i = 1:Npc-1;    % Loop over the elements


    if i == 1;      % Element 1 is pure structural
        
        Mpc = Mpc + apc(:,:,i)'*Mec*apc(:,:,i);
        Cpc = Cpc + 0;
        Kpc = Kpc + apc(:,:,i)'*Kec*apc(:,:,i);
        
        
    else            % Elements 2-5 are hydro-elastic elements 
        
        Mpc = Mpc + apc(:,:,i)'*Mehydro*apc(:,:,i);
        Cpc = Cpc + apc(:,:,i)'*Cehydro*apc(:,:,i);
        Kpc = Kpc + apc(:,:,i)'*Kehydro*apc(:,:,i);
        
    end
end

Mpc = Mpc + Melong; % Including the hydrodynamic sway and roll effect at the ends of
Cpc = Cpc + Celong; % the pontoons for the longitudional motion of the 
                    % pontoons.
                    

%end









