function [xe,ye,angle] = Bergsoy_pc_element_node_position

% Function for reporting the positions in space for the 1st node
% of the hydro-elastic elements that model the pontoons.
%
% The posistion matrices xe and ye are produced as [4x7]-matrices where
% the row numbers indicate element number and the column numbering
% indicates which pontoon the element is modelling.
%
%
%
% By Axel Wullf Wathne, 2012
%

npc = 7;       % Number of pontoons
Lp  = 30;      % Length of pontoons
Lep = Lp/4;    % Length of pontoon elements
Nel = 28;      % Number of elements

% Establishing the orientation in space for the seven sub-systems

% Defining the arch shape as function of the x-position of each node.

R    = 1300;   % Radius of the horizontal arch.
Nsup = 25;     % Nodes along the bridge span.
L    = 840;    % Length of bridge in x-direction

% Arch height at mid-point, deltamid.

hmid     = sqrt(R^2 - (L/2)^2);
deltamid = R - hmid;

% Vectors for the x- and y-postion of the nodes along the bridge
% superstructure.

x = (-L/2: L/(Nsup-1) : L/2);

y = zeros(1,length(x));

deltay = zeros(1,length(x));


% Postion of each node in the y-plane corresponding with x-position

for i = 1:length(x);

y(i) = sqrt(R^2 - x(i)^2);    % Function for a circle, defining the y-position 
                              % according to x-postion.
                        
deltay(i) = y(i) - hmid;      % The postion above the x-axis in the y-direction 
                              % of node i along the bridge span.

end


% Defining the positions of connection points between the arch bridge span
% and the pontoons in space.

xpos = [x(4) x(7) x(10) x(13) x(16) x(19) x(22)];
ypos = [deltay(4) deltay(7) deltay(10) deltay(13) deltay(16) deltay(19) deltay(22)];


% Defining the orientation of each element in space (dx, dy and Le)

dx = L/(Nsup-1);        % Lenght of each element in the x-direction.
dy = zeros(Nsup-1,1);   % Vector for the dy lengths of the elements.
Le = zeros(Nsup-1,1);   % Vector for the total lengths of the elements.


for i = 1:Nsup-1;       % Loop over the arch elements

dy(i) = deltay(i+1) - deltay(i);      % Length of element i in y-direction.

Le(i) = sqrt(dx*dx + dy(i)*dy(i));    % Total length of element i.


end


% Vector for the angles at the mid-node of the pontoon sub-systems relative
% to the global x-axis

xx=zeros(7,1);

% Inserting the respective angles
xx(1) = ((atan(dy(3)/dx))  + (atan(dy(4)/dx)))*0.5;
xx(2) = ((atan(dy(6)/dx))  + (atan(dy(7)/dx)))*0.5;
xx(3) = ((atan(dy(9)/dx))  + (atan(dy(10)/dx)))*0.5;
xx(4) = ((atan(dy(12)/dx)) + (atan(dy(13)/dx)))*0.5;
xx(5) = ((atan(dy(15)/dx)) + (atan(dy(16)/dx)))*0.5;
xx(6) = ((atan(dy(18)/dx)) + (atan(dy(19)/dx)))*0.5;
xx(7) = ((atan(dy(21)/dx)) + (atan(dy(22)/dx)))*0.5;

angle = zeros(1,Nel);

for i = 0:npc-1;  % Loop over the pontoons to apply the orientation of the
                  % pontoons to the elements making up the pontoon.
    
angle(1+4*i) = xx(i+1);
angle(2+4*i) = xx(i+1);
angle(3+4*i) = xx(i+1);
angle(4+4*i) = xx(i+1);

end


% Postion in space of the first node of the elements in contact with the
% water as xe and ye vectors.

xe = zeros(1,Nel);
ye = zeros(1,Nel);

% Defining the x-y-position of the elements that has their first nodes at
% the point of connection between the arch and pontoons.
xe(3)  = xpos(1);
xe(7)  = xpos(2);
xe(11) = xpos(3);
xe(15) = xpos(4);
xe(19) = xpos(5);
xe(23) = xpos(6);
xe(27) = xpos(7);

ye(3)  = ypos(1);
ye(7)  = ypos(2);
ye(11) = ypos(3);
ye(15) = ypos(4);
ye(19) = ypos(5);
ye(23) = ypos(6);
ye(27) = ypos(7);

for i = 0:npc-1; % Looping the pontoons to determine the x-y-position of 
                 % remaining elements of each pontoon.

xe(1+4*i) = xe(3+4*i) + 2*Lep*sin(xx(1+i));
xe(2+4*i) = xe(3+4*i) +   Lep*sin(xx(1+i));
xe(4+4*i) = xe(3+4*i) -   Lep*sin(xx(1+i));

ye(1+4*i) = ye(3+4*i) - 2*Lep*cos(xx(1+i));
ye(2+4*i) = ye(3+4*i) -   Lep*cos(xx(1+i));
ye(4+4*i) = ye(3+4*i) +   Lep*cos(xx(1+i));

end


end