function [Cehydro,Celong] = Bergsoy_pc_hydroelastic_damping_matrix(Jp,dx,Ap,Bp,hp,Cyy,Czz,Crr,Cxx)
%
% Purpose:     Determination of a damping matrix for a hydroelastic 
%              3D beam element with twelve degrees of freedom
%              in a local element coordinate system
%
%              The structural damping is not included in the formulation of
%              the damping matrix. The damping matrix apply to elements in
%              contact with the surrounding fluid and incorporates the
%              damping coefficients in sway, heave and roll. The damping
%              matrix is developed by similar means as the mass matrix,
%              only with the damping coefficients introduced in stead of
%              the mass properties.
%         
%              
%              Firstly, a mass matrix containing the terms expressing the 
%              horisontal displacements is established. This matrix is 
%              multiplied with the hydrodynamic damping coeffiecient in sway 
%              direction to express the damping effect for this motion, Cehor. 
%              
%              Secondly, a mass matrix is established containing the terms
%              expressing the vertical displacement of the element. This
%              matrix is multiplied with the hydrodynamic damping 
%              coefficient in heave motion, Cever.
%
%              Thirdly, a matrix is established, containing terms for the
%              torsional displacement of the element. This element is thus
%              multiplied with the hydrodynamic damping coefficient for 
%              roll motion to produce Ceroll.
%              
%
%              These matrices are ultimately added to form the complete
%              hydrodynamic damping matrix for the element.
%
%  
% Input:     
%             Jp  - torsional moment of inertia of the pontoon element
%             dx  - length of the element
%             Ap  - pontoon cross-sectional area
%            Cyy  - hydrodynamic damping for sway motion 
%            Czz  - hydrodynamic damping for heave motion 
%            Crr  - hydrodynamic damping for torsional motion 
%            Cxx  - hydrodynamic damping for surge motion  
%         
%
%              
%
%
% Output: Cehydro - damping matrix of hydrodynamic effects for a 3D-12DOF
%                   hydro-elastic element.
%         Celong  - damping matrix for longitudinal motion of a pontoon
%                   sub-system, 36x36 matrix.
%
%
%
% By Axel Wullf Wathne, 2012.
%

Le = dx;        % Element length


% Hydrodynamic damping matrix

% Establishing a mass matrix assosiated with the displacement in
% the horisontal xy-plane, sway. (DOF's 2,5,8 & 11)

Mehor = zeros(12);

Mehor(2,2)  = 156;
Mehor(5,2)  = 22*Le;
Mehor(8,2)  = 54;
Mehor(11,2) = -13*Le;

Mehor(5,5)  = 4*Le^2;
Mehor(8,5)  = 13*Le;
Mehor(11,5) = -3*Le^2;

Mehor(8,8)  = 156;
Mehor(11,8) = -22*Le;

Mehor(11,11) = 4*Le^2;

for i=1:12;
    for j=1:12;
        Mehor(i,j)=Mehor(j,i);
    end
end

Cehor = Mehor.*(Cyy/420);


% Establishing a mass matrix assosiated with the displacement in the 
% vertical xz-plane, heave. (DOF's 3,6,9 & 12)

Mever = zeros(12);

Mever(3,3)  = 156;
Mever(6,3)  = 22*Le;
Mever(9,3)  = 54;
Mever(12,3) = -13*Le;

Mever(6,6)  = 4*Le^2;
Mever(9,6)  = 13*Le;
Mever(12,6) = -3*Le^2;

Mever(9,9) = 156;
Mever(12,9) = -22*Le;

Mever(12,12) = 4*Le^2;

for i=1:12;
    for j=1:12;
        Mever(i,j)=Mever(j,i);
    end
end

Cever = Mever.*(Czz/420);


% Establishing a mass matrix assosiated with the displacement in the
% torsional yz-plane, roll. (DOF's 4 & 10)

Meroll = zeros(12);

Meroll(4,4)  = 140*Jp/Ap;
Meroll(10,4) = 70*Jp/Ap;

Meroll(4,10) = 70*Jp/Ap;
Meroll(10,10) = 140*Jp/Ap;

Ceroll = Meroll.*(Crr/420);


% Additional damping contribution due to the coupled motion of heave-roll 
% and sway-roll.

% As a pontoon is rotated (roll-motion) vertical motion of the pontoon is
% experienced as a function of the distance away from the rotational axis.

Chr = zeros(12);

chr = (Bp*Czz*Le)/24;

Chr(4,4)   = 2;
Chr(4,10)  = 1;
Chr(10,4)  = 1;
Chr(10,10) = 2;

Chr = Chr.*chr;              % Hydrodynamic damping matrix for the heave 
                            % motion resulting from roll motion.
                            
% As a pontoon is rotated (roll-motion) horizontal motion of the pontoon is
% also experienced as a function of the distance above or below the
% rotational axis of the pontoon.

Csr = zeros(12);

csr = (hp*Cyy*Le)/24;

Csr(4,4)   = 2;
Csr(4,10)  = 1;
Csr(10,4)  = 1;
Csr(10,10) = 2;

Csr = Csr.*csr;              % Hydrodynamic damping matrix for the sway 
                            % motion resulting from roll motion.


% Assembly of the mass matrix for the hydroelastic element

Cehydro = Cehor + Cever + Ceroll + Chr + Csr;


% Additonal hydrodynamic damping matrix to include hydrodynamic effects at the
% ends of each pontoon. 

% Damping matrix for ndofpc   
Melonga = zeros(36);   

Melonga(7,7)   = 140;    % Axial displacement of node 2, d7.
Melonga(31,31) = 140;    % Axial displacement of node 6, d31.
Melonga(7,31)  = 70;
Melonga(31,7)  = 70;

Celonga = Melonga.*(Cxx/420);  % Added damping matrix for the the sway motion
                               % in the longitudional direction of the
                               % pontoons.

                                  

                                  
Celong = Celonga;


end
