function [Mehydro,Melong] = Bergsoy_pc_hydroelastic_mass_matrix(denc,Jp,dx,Ap,Bp,hp,Myy,Mzz,Mrr,Mxx)
%
% Purpose:     Determination of a mass matrix for a hydroelastic 
%              3D beam element with twelve degrees of freedom
%              in a local element coordinate system
%
%              A structural mass matrix is established, Mes, to express the
%              structural mass of the element. 
%              
%              Secondly, a mass matrix containing the terms expressing the 
%              horisontal displacements is established. This matrix is 
%              multiplied with the hydrodynamic added mass in the sway 
%              direction to express the added mass for this motion, Mehor. 
%              
%              Thirdly, a mass matrix is established containing the terms
%              expressing the vertical displacement of the element. This
%              matrix is multiplied with the added mass in heave motion,
%              Mever.
%
%              A fourth matrix is established, containing terms for the
%              torsional displacement of the element. This element is thus
%              multiplied with the torsional hydrodynamic mass to express
%              the added mass in roll motion, Meroll.
%
%              Matrices are developed to include the effect of heave and
%              sway motion as a function of roll. 
%
%              These matrices are ultimately added to form the complete
%              hydrodynamic mass matrix for the element.
%
%              A final matrix of the size of the pc-sub-system DOF's are
%              constructed to include the surge effects due to axial motion
%              of the pc-sub-system
%
%  
% Input:    denc  - density of element material, concrete
%             Jp  - torsional moment of inertia of the element
%             dx  - length of the element
%             Ap  - cross-sectional area of the pontoons
%          msway  - hydrodynamic mass for sway motion [kg]
%         mheave  - hydrodynamic mass for heave motion [kg]
%          mroll  - hydrodynamic mass for torsional motion [kg]
%         msurge  - hydrodynamic mass for surge motion [kg]
%         mpitch  - hydrodynamic mass for pitch motion [kg]
%
%
%              The hydrodynamic masses are determined in translation (sway
%              and heave) from the hydrodynamic coefficients by
%              multiplication with rhow*B*d*L, and for the added mass in
%              roll motion by multiplication with rhow*B*d*L^2.
%
%
% Output: Mehydro - mass matrix including hydrodynamic effects 
%         Melong  - mass matrix for longitudinal motion of pontoon
%
%
%
% By Axel Wullf Wathne, 2012.
%

Le = dx;            % Lenght of hydro-elastic element

% Structural mass matrix Mes [12x12]

me = denc*Ap*Le;      % Total mass of the element [kg]

Mes = zeros(12);

Mes(1,1) = 140;
Mes(7,1) = 70; 

Mes(2,2)  = 156;
Mes(5,2)  = 22*Le;
Mes(8,2)  = 54;
Mes(11,2) = -13*Le;

Mes(3,3)  = 156;
Mes(6,3)  = 22*Le;
Mes(9,3)  = 54;
Mes(12,3) = -13*Le;

Mes(4,4)  = 140*Jp/Ap;
Mes(10,4) = 70*Jp/Ap;

Mes(5,5)  = 4*Le^2;
Mes(8,5)  = 13*Le;
Mes(11,5) = -3*Le^2;

Mes(6,6)  = 4*Le^2;
Mes(9,6)  = 13*Le;
Mes(12,6) = -3*Le^2;

Mes(7,7) = 140;

Mes(8,8)  = 156;
Mes(11,8) = -22*Le;

Mes(9,9) = 156;
Mes(12,9) = -22*Le;

Mes(10,10) = 140*Jp/Ap;
Mes(11,11) = 4*Le^2;
Mes(12,12) = 4*Le^2;

for i=1:12;
    for j=1:12;
        Mes(i,j)=Mes(j,i);
    end
end

Mes = Mes.*(me/420);


% Hydrodynamic mass matrix

% Establishing a mass matrix assosiated with the displacement in
% the horisontal xy-plane, sway. (DOF's 2,5,8 & 11)

Mehor = zeros(12);

Mehor(2,2)  = 156;
Mehor(5,2)  = 22*Le;
Mehor(8,2)  = 54;
Mehor(11,2) = -13*Le;

Mehor(5,5)  = 4*Le^2;
Mehor(8,5)  = 13*Le;
Mehor(11,5) = -3*Le^2;

Mehor(8,8)  = 156;
Mehor(11,8) = -22*Le;

Mehor(11,11) = 4*Le^2;

for i=1:12;
    for j=1:12;
        Mehor(i,j)=Mehor(j,i);
    end
end

Mehor = Mehor.*(Myy/420);    % Added mass matrix for horisontal xy-plane.


% Establishing a mass matrix assosiated with the displacement in the 
% vertical xz-plane, heave. (DOF's 3,6,9 & 12)

Mever = zeros(12);

Mever(3,3)  = 156;
Mever(6,3)  = 22*Le;
Mever(9,3)  = 54;
Mever(12,3) = -13*Le;

Mever(6,6)  = 4*Le^2;
Mever(9,6)  = 13*Le;
Mever(12,6) = -3*Le^2;

Mever(9,9) = 156;
Mever(12,9) = -22*Le;

Mever(12,12) = 4*Le^2;

for i=1:12;
    for j=1:12;
        Mever(i,j)=Mever(j,i);
    end
end

Mever = Mever.*(Mzz/420);   % Added mass matrix for vertical xz-plane.


% Establishing a mass matrix assosiated with the displacement in the
% torsional yz-plane, roll. (DOF's 4 & 10)

Meroll = zeros(12);

Meroll(4,4)  = 140*Jp/Ap;
Meroll(10,4) = 70*Jp/Ap;

Meroll(4,10) = 70*Jp/Ap;
Meroll(10,10) = 140*Jp/Ap;

Meroll = Meroll.*(Mrr/420);  % Added mass matrix for roll, yz-plane.


% Additional mass contribution due to the coupled motion of heave-roll and
% sway-roll.

% As a pontoon is rotated (roll-motion) vertical motion of the pontoon is
% experienced as a function of the distance away from the rotational axis.

Mhr = zeros(12);

mhr = (Bp*Mzz*Le)/24;

Mhr(4,4)   = 2;
Mhr(4,10)  = 1;
Mhr(10,4)  = 1;
Mhr(10,10) = 2;

Mhr = Mhr.*mhr;              % Added mass matrix for the heave motion resulting
                            % from roll motion.
                            
% As a pontoon is rotated (roll-motion) horizontal motion of the pontoon is
% also experienced as a function of the distance above or below the
% rotational axis of the pontoon.

Msr = zeros(12);

msr = (hp*Myy*Le)/24;

Msr(4,4)   = 2;
Msr(4,10)  = 1;
Msr(10,4)  = 1;
Msr(10,10) = 2;

Msr = Msr.*msr;              % Added mass matrix for the sway motion resulting
                            % from the roll motion.
                            



% Assembly of the mass matrix for the hydroelastic element

Mehydro = Mes + Mehor + Mever + Meroll + Mhr + Msr;


% Additonal hydrodynamic mass matrix to include hydrodynamic effects at the
% ends of each pontoon due to surge motion. 

% Mass matrix for ndofpc

Melonga = zeros(36);   
     

Melonga(7,7)   = 140;    % Axial displacement of node 2, d7.
Melonga(31,31) = 140;    % Axial displacement of node 6, d31.
Melonga(7,31)  = 70;
Melonga(31,7)  = 70;
  
Melonga = Melonga.*(Mxx/420);     % Added mass matrix for the the sway motion
                                  % in the longitudional direction of the
                                  % pontoons.

                                  

                                  
Melong = Melonga;



end
