function [Kehydro] = Bergsoy_pc_hydroelastic_stiffness_matrix(g,d,rhow,Ec,nuc,dx,Ap,Iyp,Izp,Jp,Bp)
%
% Purpose:     Determination of a stiffness matrix for 
%              a 3D hydroelastic beam element.
%
%              The hydrostatic stiffness contribution is purely vertical
%              and only applies to vertical displacement of a pontoon.
%              Vertical displacement is described through the element DOF's
%              in the vertical plane and by the rotational DOF's as
%              function of the distance from the axis of rotation.
%
%              The three dimensional stiffness matrix is of dimension 
%              [12x12] as the 3D beam element has a total of 12 DOF's.
%
%              The hydrostatic stiffness contribution is expressed through
%              an integration of the shape functions of the beam element
%              and is resultingly expressed by the same matrix as is used
%              for the beam element mass matrix.
%
%
%
% Input:       Ec - Young's modulus for high strenght concrete
%             nuc - Poisson's ratio for high strenght concrete
%              dx - element length
%              Ap - cross-sectional area of the pontoons
%             Izp - moment of inertia of pontoon cross-section about z axis
%             Iyp - moment of inertia of pontoon cross-section about y axis
%             Jp  - polar moment of inertia of the pontoons
%             Bp  - width of pontoon in the fluid
%
% Output: Kehydro - stiffness matrix for hydroelastic element 
%
%

Le = dx;                      % Element lenght

GMt  = 6.2;                    % Transverse metacentric height of pontoon 
kB   = Bp*rhow*g;              % Buoyancy stiffness per unit length of the pontoon/element
kBr  = rhow*g*Bp*d*GMt;        % Rotational buyancy stiffness per unit length 
G    = Ec/(2*(1+nuc));         % Shear modulous of elasticity
Ke   = zeros(12,12);           % 3D stiffness matrix, dimensions [12x12]
Kehz = zeros(12,12);           % 3D hydrostatic stiffness matrix for vertical motion
Kehr = zeros(12,12);           % 3D hydrostatic stiffness matrix for roll motion
kt   = (Ap*Ec/Le)*[1 -1;-1 1]; % Axial stiffness matrix
ktor = (Jp*G/Le)*[1 -1;-1 1];  % Torsional stiffness matrix


kbeam = [  12/Le^3     6/Le^2    -12/Le^3    6/Le^2 ;
             6/Le^2     4/Le       -6/Le^2    2/Le  ;
          - 12/Le^3    -6/Le^2     12/Le^3   -6/Le^2;
             6/Le^2     2/Le       -6/Le^2    4/Le   ];
     
khydro = [  156    22*Le       54    -13*Le  ;
           22*Le    4*Le^2   13*Le    -3*Le^2;
             54    13*Le      156    -22*Le  ;  
          -13*Le   -3*Le^2  -22*Le     4*Le^2 ];


                            
      
% Structural stiffness
     
Ke([1 7],[1 7]) = kt;                     % Axial stiffness

Ke([4 10],[4 10]) = ktor;                 % Torsional stiffness

Ke([2 5 8 11],[2 5 8 11]) = kbeam*Ec*Izp; % Bending stiffness for the horisontal
                                          % xy-plane.
                                        
Ke([3 6 9 12],[3 6 9 12]) = kbeam*Ec*Iyp; % Bending stiffness for the vertical
                                          % xz-plane.
                                        

% Hydrostatic restoring stiffness contribution in the z-direction
                                        
Kehz([3 6 9 12],[3 6 9 12]) = khydro.*((kB*Le)/420); % Allocating the hydrostatic
                                                   % contributions
                                                   % correctly in the 3D
                                                   % stiffness matrix.

                                                   
% Hydrostatic stiffness contribution in roll motion


Kehr([4 10],[4 10]) = (kBr*(Le/6)).*[2 1;
                                   1 2];                                                   
                                                   
                                                   
                                                   
Kehydro = Ke + Kehz + Kehr;                    
                                        % Summation of the structural and 
                                        % hydrostatic stiffness
                                        % contributions.

 end







                       
                  
                  
                  
                  
                  
                  