function [MpcG,CpcG,KpcG] = Bergsoy_pc_transformation_mass_damping_stiffness(ndofpc,Myy,Mzz,Mrr,Mxx,Cyy,Czz,Crr,Cxx)

%
% Transformation of the property matrices of the pontoon-connector
% sub-systems to apply to global coordinates.
%
% The pc-sub-system is introduced seven times in the 3D model of Bergsysund 
% floating bridge, each time with different orientation. The orientation of the
% pontoons are assumed normal to the node at the superstructure where 
% it is connected. Consequently, the pc-sub-systems will have local
% coordinate axes different from the global coordinate axes of the 3D
% floating bridge model.
%
% Transformation matrices, Trpc, have been developed for each of the
% pc-sub-system to describe its orientation with respect to the global
% axes. These transformation matrices are employed to determine the
% property matrices (mass, damping, stiffness) of each of the
% pc-sub-systems with respect to the global coordinates.
%
% Due to the different orientation of the pc-sub-systems, different
% property matrices will be calculated for each sub-system as functions of
% their orientation in space.
%
% Input:  hydrodynamic coefficients
%         Trpc - transformation matrices for pc-sub-system
%         Mpc  - mass matrix for the pc-sub-system in local coordinates
%         Cpc  - damping matrix for the pc-sub-system in local coordinates
%         Kpc  - stiffness matrix for the pc-sub-system in local coordinates
%
% Output: MpcG - mass matrices for each pc-sub-system oriented in global
%                coordinates.
%         CpcG - damping matrices for each pc-sub-system oriented in global
%                coordinates.
%         KpcG - stiffness matrices for each pc-sub-system oriented in
%                global coordinates.
%
%
% Functions: Bergsoy_pc_transformation_matrices.m
%            Bergsoy_pc_assembly_local.m
%
%
% By Axel Wullf Wathne
%

npc  = 7;      % Number of pc-sub-systems introduced in the floating bridge model
     


% Importing the transformation matrices for the pc-sub-system. These
% matrices are stored in a matrix array where Trpc(:,:,i) is the
% transformation matrix that links the i'th sub-system to global
% coordinates.

[Trpc] = Bergsoy_pc_transformation_matrices;


% Importing the property matrices of the pc-sub-system in local coordinates

[Mpc,Cpc,Kpc] = Bergsoy_pc_assembly_local(ndofpc,Myy,Mzz,Mrr,Mxx,Cyy,Czz,Crr,Cxx);


% Transformation of the local property matrices of each of the
% pc-sub-systems to apply in the global coordinate system

MpcG = zeros(ndofpc,ndofpc,npc);     % Establishing the property matrices of the sub-system
CpcG = zeros(ndofpc,ndofpc,npc);     % with respect to global axes. [36x36x7]
KpcG = zeros(ndofpc,ndofpc,npc);


for i = 1:npc;      % Loop over the sub-systems. Transform the DOF's of each
                    % of them to the global coordinate system by
                    % transforming the property matrices.
    
    
    MpcG(:,:,i) = Trpc(:,:,i)'*Mpc*Trpc(:,:,i);
    CpcG(:,:,i) = Trpc(:,:,i)'*Cpc*Trpc(:,:,i);
    KpcG(:,:,i) = Trpc(:,:,i)'*Kpc*Trpc(:,:,i);
    
end

end

    
    
    
    
    
    
    
    