function [Trpc] = Bergsoy_pc_transformation_matrices

% Transformation matrices for transformation of mass, damping and stiffness
% matrices of the pontoon-connector sub-systems to apply to the global 
% coordinate axes.
% 
% The property matrices of the pontoon-connector sub-systems (mass, damping
% and stiffness) are to be transformed according to their placement along
% bridge superstructure. For this model, seven pontoon-connector sub-systems
% are introduced along the superstructure of the floating bridge. These are
% attached to nodes 4,7,10,13,16,19&22 of the bridge superstructure. 
% If the pontoon-connector sub-systems are assumed to be placed with the pontoons
% coinciding with the global x-axis, no transformation of their property
% matrices is necessary. However, if the pontoons are assumed to be placed
% normal to the bridge superstructure at the point of connection, the property
% matrices of the pontoon-connector sub-system need to be transformed for
% each of the sub-systems according to their position in space.
%
% The transformation matrices are developed under the assumption that the 
% local x-axis of the pontoons are aligned normal to the above superstructure
% element. This is done by applying an angle of orientation of the pontoon
% equal to the mean of the two superstructure elements connected to the
% same node as the pontoon-connector sub-system is introduced to, plus an
% additonal pi/2.
%
% Consequently, seven tranformation matrices are developed, one for each of 
% the pontoon sub-systems.
%
%
% Each of the pontoon-connector sub-systems have 6 nodes with three
% translational DOF's and three rotational DOF's. These DOF's are
% transformed to the global coordinate system according to the angles
% between the local and global axes.
%
%
% By Axel Wullf Wathne, 2012.
%



% Properties of the pontoon-connector sub-system

Npc    = 6;   % Number of nodes for the pontoon-connector sub-system
ndofpc = 36;  % DOF's of the sub-system
npc    = 7;   % Number of pc-sub-systems introduced to the model


% Establishing the orientation in space for the seven sub-systems

% Defining the arch shape as function of the x-position of each node.

R    = 1300;   % Radius of the horizontal arch.
Nsup = 25;     % Nodes along the bridge span.
L    = 840;    % Length of bridge in x-direction

% Arch height at mid-point, deltamid.

hmid     = sqrt(R^2 - (L/2)^2);
deltamid = R - hmid;

% Vectors for the x- and y-position of the nodes along the bridge
% superstructure.

x = -L/2: L/(Nsup-1) : L/2;

y = zeros(1,length(x));

deltay = zeros(1,length(x));


% Postion of each node in the y-plane corresponding with x-position

for i = 1:length(x);

y(i) = sqrt(R^2 - x(i)^2);    % Function for a circle, defining the y-position 
                              % according to x-postion.
                        
deltay(i) = y(i) - hmid;      % The postion above the x-axis in the y-direction 
                              % of node i along the bridge span.

end


% Defining the orientation of each element of the arched superstructure in 
% space (dx, dy and Le)

dx = L/(Nsup-1);         % Lenght of each element in the x-direction.
dy = zeros(Nsup-1,1);    % Vector for the dy lengths of the elements.
Le = zeros(Nsup-1,1);    % Vector for the total lengths of the elements.

for i = 1:Nsup-1;

dy(i) = deltay(i+1) - deltay(i);      % Length of element i in y-direction.

Le(i) = sqrt(dx*dx + dy(i)*dy(i));    % Total length of element i.

end



% Establishing transformation matrices according to the orientation of each
% of the sub-systems. 

ttrans = zeros(3,3,npc);        % Transformation matrix for the translational DOF's for a single node

trota  = zeros(3,3,npc);        % Transformation matrix for the rotational DOF's for a single node

Trpc = zeros(ndofpc,ndofpc,npc);% Transformation matrix for a sub-system, stored in a matrix array


xx=zeros(npc,1);
yy=zeros(npc,1);
zz=zeros(npc,1);

% Om(i) - average angle at nodes of attachment.
Om(1) = (((atan(dy(3)/dx)) + (atan(dy(4)/dx)))*0.5);
Om(2) = (((atan(dy(6)/dx)) + (atan(dy(7)/dx)))*0.5);
Om(3) = (((atan(dy(9)/dx)) + (atan(dy(10)/dx)))*0.5);
Om(4) = (((atan(dy(12)/dx)) + (atan(dy(13)/dx)))*0.5);
Om(5) = (((atan(dy(15)/dx)) + (atan(dy(16)/dx)))*0.5);
Om(6) = (((atan(dy(18)/dx)) + (atan(dy(19)/dx)))*0.5);
Om(7) = (((atan(dy(21)/dx)) + (atan(dy(22)/dx)))*0.5);


for m = 1 : 4;         % Loop over the first four pc-sub-systems
                       % The angles of the pc-sub-systems are taken as the
                       % mean angle of the above superstructure elements
                       % and added to pi/2.
    
    xx(m) = (pi/2) + abs(Om(m));
    yy(m) = xx(m);
    zz(m) = 0;              % No rotation of the z-axis
    
    xy(m) = Om(m);
    yx(m) = pi + abs(Om(m));
    
    zx(m) = pi/2;           % The z-axis is still oriented normal to the
    zy(m) = pi/2;           % x- and y-axis.
    xz(m) = pi/2;
    yz(m) = pi/2;
    
end

for m = 5 : npc;       % Loop over the last three pc-sub-systems
    
    xx(m) = (pi/2) - abs(Om(m));
    yy(m) = xx(m);
    zz(m) = 0;              % No rotation of the z-axis
    
    xy(m) = Om(m);
    yx(m) = pi/ - abs(Om(m));
    
    zx(m) = pi/2;           % The z-axis is still oriented normal to the
    zy(m) = pi/2;           % x- and y-axis.
    xz(m) = pi/2;
    yz(m) = pi/2;
    
end

for m = 1 : npc;        % Loop over all seven pc-sub-systems to allocate the
                        % translational and rotational transformation
                        % matrices properly into global transformation
                        % matrices, Tr(:,:,i) of the i sub-systems.
    
    
    ttrans(:,:,m) = [cos(xx(m)) cos(xy(m)) cos(xz(m));
                     cos(yx(m)) cos(yy(m)) cos(yz(m));
                     cos(zx(m)) cos(zy(m)) cos(zz(m))];
                 
                 
    trota(:,:,m) = [cos(xx(m)) cos(xz(m)) cos(xy(m));
                    cos(zx(m)) cos(zz(m)) cos(zy(m));
                    cos(yx(m)) cos(yz(m)) cos(yy(m))];
                
                
    Trpc([1 2 3],[1 2 3],m) = ttrans(:,:,m);
    Trpc([4 5 6],[4 5 6],m) = trota(:,:,m);
    Trpc([7 8 9],[7 8 9],m) = ttrans(:,:,m);
    Trpc([10 11 12],[10 11 12],m) = trota(:,:,m);
    Trpc([13 14 15],[13 14 15],m) = ttrans(:,:,m);
    Trpc([16 17 18],[16 17 18],m) = trota(:,:,m);
    Trpc([19 20 21],[19 20 21],m) = ttrans(:,:,m);
    Trpc([22 23 24],[22 23 24],m) = trota(:,:,m);
    Trpc([25 26 27],[25 26 27],m) = ttrans(:,:,m);
    Trpc([28 29 30],[28 29 30],m) = trota(:,:,m);
    Trpc([31 32 33],[31 32 33],m) = ttrans(:,:,m);
    Trpc([34 35 36],[34 35 36],m) = trota(:,:,m);
    
end
    
    % The transformation matrix for pontoon-connector sub-system i is then
    % stored in the matrix array as Trpc(:,:,i). This transformation matrix
    % is further applied to transform the property matrices of the
    % pontoon-connector sub-system to global coordinates. Assuming its
    % position in space as stated herein.
    
    
end
    