function [Kesup] = Bergsoy_sup_structural_stiffness_matrix(Es,nus,Le,Nsup,Asup,Iys,Izs,Jsup)
%
% Purpose:     Determination of stiffness matrices for 
%              a 3D beam element with twelve degrees of freedom
%              in a local element coordinate system. The three dimensional
%              stiffness matrix is of dimension [12x12] as the 3D beam
%              element has a total of 12 DOF's.
%              A stiffness matrix is developed for each member along the
%              bridge span as the length vary some for the elements over
%              the length of the bridge. These matrices are stored in a
%              matrix array.
%            
%  
% Input:       E  - Young's modulus
%              nu - Poisson's ratio
%              Le - length of the member
%              A  - cross-sectional area
%              Iz - moment of inertia of cross-section about z axis
%              Iy - moment of inertia of cross-section about y axis
%              J  - polar moment of inertia
%
% Output:   Kesup - stiffness matrix array
%
%
% By Axel Wullf Wathne, 2012.
%


Kesup = zeros(12,12,(Nsup-1));     % Matrix array for the stiffness matrices of each
                                   % of the elements along the superstructure

for i = 1:(Nsup-1);                % Loop over the elements
    

G           = Es/(2*(1+nus));
kt(:,:,i)   = (Asup*Es/Le(i))*[1 -1;-1 1];
ktor(:,:,i) = (Jsup*G/Le(i))*[1 -1;-1 1];

kbeam(:,:,i) = [  12/Le(i)^3     6/Le(i)^2    -12/Le(i)^3    6/Le(i)^2; 
               6/Le(i)^2     4/Le(i)       -6/Le(i)^2    2/Le(i)  ;
             -12/Le(i)^3    -6/Le(i)^2     12/Le(i)^3   -6/Le(i)^2;
               6/Le(i)^2     2/Le(i)       -6/Le(i)^2    4/Le(i)   ];
     

     
Kesup([1 7],[1 7],i) = kt(:,:,i);
Kesup([4 10],[4 10],i) = ktor(:,:,i);
Kesup([2 5 8 11],[2 5 8 11],i) = kbeam(:,:,i)*Es*Izs;
Kesup([3 6 9 12],[3 6 9 12],i) = kbeam(:,:,i)*Es*Iys;

end


end



