function [MsupG,KsupG] = Bergsoy_superstructure_assembly_mass_stiffness

%
% Asssembly of the superstructure sub-system for the 3D Bergsysundet 
% floating bridge model, in global coordinates.
%
% The mass and stiffness matrices of each element that makes up the bridge
% superstructure are assembled to establish the mass and stiffness matrices
% for the superstructure sub-system. This is done by the use of the
% connectivity matrices for the superstructure, linking each of the 24
% elements along the bridge span to the sub-system DOF's. 
%
% In order for these connectivity matrices to be valid, the element mass
% and stiffness matrices employed in the assembly of the sub-system mass 
% stiffness matrices have to be transformed to the global coordinate
% system. MeG = Tr'*Me*Tr and KeG = Tr'*Ke*Tr
%
% As the superstructure is not in contact with the fluid. There is no
% damping matrix assembled for this sub-system.
%
%
% Input: MeG - Element mass matrix in global coordinates
%        KeG - Element stiffness matrix in global coordinates
%       asup - Connectivity matrices for all the elements
%
%
% Output: MsupG - Mass matrix for the superstructure sub-system 
%         KsupG - Stiffness matrix for the superstructure sub-system 
%
%
% Functions: Bergsoy_superstructure_transform_mass_stiffness.m
%            Bergsoy_superstructure_connectivity_matrices.m
%
%
%
% By Axel Wullf Wathne
%



% Superstructure sub-system properties

Nsup = 25;         % Number of nodes along the bridge superstructure



% Importing the element mass and stiffness matrices in global coordinates
% as matrix arrays.

[MesupG,KesupG] = Bergsoy_superstructure_transform_mass_stiffness(Nsup);


% Importing the connectivity matrices for the superstructure stored in a
% matrix array and corresponding to each element along the superstructure.

[asup,ndofsup] = Bergsoy_superstructure_connectivity_matrices(Nsup);


% Both the element mass and stiffness matrices and the connectivity
% matrices are stored in matrix arrays of length Nsup-1 = 24. The first
% matrices in each array corresponds to the first element and so on..


% Establishing superstructure sub-system property matrices


MsupG = zeros(ndofsup);

KsupG = zeros(ndofsup);


for i = 1 : Nsup-1;    % Loop over all elements
    
    MsupG = MsupG + asup(:,:,i)'*MesupG(:,:,i)*asup(:,:,i);
    
    KsupG = KsupG + asup(:,:,i)'*KesupG(:,:,i)*asup(:,:,i);
    
end


end


