function [MesupG,KesupG] = Bergsoy_superstructure_transform_mass_stiffness(Nsup)

%
% Transformation of the element mass and stiffness matrices for the 3D 
% Bergsysund floating bridge superstructure.
%
% Each of the elements making up the superstructure of the
% 3D floating bridge has an individual transformation matrix,
% relating the DOF's of that element to the global coordinate system. These
% transformation matrices are extracted and applied to the 3D-12DOF
% structural mass and stiffness matrices so that these matrices also are
% related to the global coordinate system.
%
% Input: Tr(:,:,m) - transformation matrices for each of the m elements
%        Me(:,:,m) - mass matrices for each of the m elements 
%        Ke(:,:,m) - stiffness matrices for each of the m elements
%             Nsup - number of nodes across the superstructure
%
%        As the superstructure is not in contact with the fluid, all the
%        mass and stiffness matrices imported are pure structral matrices.
%
% Output: MeG(:,:,m) - element mass matrices related to global coordinates
%         KeG(:,:,m) - element stiffness matrices related to global
%                      coordinates.
%
%
% Functions: floating_bridge_3D_superstructure_transformation_matrices.m
%            floating_bridge_3D_sup_structural_mass_matrix.m
%            floating_bridge_3D_sup_structural_stiffness_matrix.m
%
%            
%
% By Axel Wullf Wathne, 2012.
%




% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
td   = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tw   = 0.01;      % thickness of side walls of the superstructure
nus  = 0.3;       % poisson's ratio for steel


% Degrees of freedom

ndofel  = 12;      % Number of DOF's for the 2D-12DOF beam element



Asup = (2*(h-td-ts)*tw)+(B*(td+ts));        % Area of superstructre cross-section, assumed hollow quadratic section [m2]

ctz  =  h - (td/2);                         % Position of center of top deck in z-direction
cwz  = (h-td+ts)/2;                         % Position of center of walls in z-direction
cbz  = ts/2;                                % Position of center of bottom deck in z-direction


cz   = (2*tw*(h-td-ts)*cwz + B*td*ctz + B*ts*cbz)/Asup; % Cross-section area center in z-direction

% 2nd moment of inertia of superstructure cross-section y-y [m4]
Iys  = (B*(td^3+ts^3) + 2*tw*(h-td-ts)^3)/12 + B*td*(ctz -cz)^2 + 2*tw*(h-td-ts)*(cwz-cz)^2 + B*ts*(cbz-cz)^2;  

% 2nd moment of inertia of superstructure cross-section z-z [m4]
Izs  = ((td+ts)*B^3 + 2*(h-td-ts)*tw^3)/12 + (h-td-ts)*tw*((B-tw)/2)^2;


Jsup = (4*h^2*B^2)/(2*(h/tw)+(B/td)+(B/ts)); % Torsional moment of the rectangular hollow box cross-section

Es   = 200E9;                                % E-modulus of steel [N/m2]

dens = 7500;                                 % Density of steel [kg/m3]



% Extracting the transformation matrices for the elements of the floating
% bridge superstructure. The Le-vector contains the individual element
% lengths of the superstructure elements.

[Trsup,Le] = Bergsoy_superstructure_transformation_matrices;



% Importing the structural mass and stiffness matrices as matrix arrays
% in local coordinates. These matrices apply to all the elements along the
% bridge superstructure. [ndofel,ndofel,Nsup-1]

[Mesup] = Bergsoy_sup_structural_mass_matrix(dens,Jsup,Le,Nsup,Asup);
    
[Kesup] = Bergsoy_sup_structural_stiffness_matrix(Es,nus,Le,Nsup,Asup,Iys,Izs,Jsup);

    

% Transforming each of the element mass and stiffness matrices to the
% global coordinate system. Applying the corresponding transformation
% matrices to the property matrices of each element.


MesupG = zeros(ndofel,ndofel,Nsup-1); % Matrix array for element mass matrices related to global coordinates

KesupG = zeros(ndofel,ndofel,Nsup-1); % Matrix array for element stiffness matrices related to global coordinates


for m = 1:(Nsup-1);    % Loop over each element
    
    MesupG(:,:,m) = Trsup(:,:,m)'*Mesup(:,:,m)*Trsup(:,:,m);
    
    KesupG(:,:,m) = Trsup(:,:,m)'*Kesup(:,:,m)*Trsup(:,:,m);
    
end
    
% The transformed property matrices of element i are then found in as
% matrices MeG(:,:,i) and KeG(:,:,i), and these are referred to the global
% coordinate axes. 
% The superstructure sub-system may then be assembled by a one-to-one 
% relation between the element DOF's and the DOF's of the sub-system.
    
end

    
    