function [Trsup,Le] = Bergsoy_superstructure_transformation_matrices
%
% Development of transformation matrices for the elements making up the
% Bergsysund bridge superstructure of the 3D floating bridge model.
%
% The superstructure of the floating bridge model has an arch in the
% horisontal x-y-plane. The arch has shape of a circle with radius R=1300m.
% This results in different orientation of the beam elements along the
% bridge span, with the elements closest to the landsides having largest
% rotation from the global coordinate system. 
%
% The element length in the global x-direction, dx, is assumed constant
% while the dy component vary for the elements along the span. This results
% in somewhat longer elements closer to the landside due to the larger
% rotations. Le = sqrt(dx^2 + dy^2). 
%
%
% By Axel Wullf Wathne, 2012.
%



% Defining the arch shape as function of the x-position of each node.

R    = 1300;   % Radius of the horizontal arch.
Nsup = 25;     % Nodes along the bridge span.
L    = 840;    % Length of bridge in x-direction

% Arch height at mid-point, deltamid.

hmid     = sqrt(R^2 - (L/2)^2);
deltamid = R - hmid;

% Vectors for the x- and y-postion of the nodes along the bridge
% superstructure.

x = (-L/2: L/(Nsup-1) : L/2);

y = zeros(1,length(x));

deltay = zeros(1,length(x));


% Postion of each node in the y-plane corresponding with x-position

for i = 1:length(x);

y(i) = sqrt(R^2 - x(i)^2);    % Function for a circle, defining the y-position 
                              % according to x-postion.
                        
deltay(i) = y(i) - hmid;       % The postion above the x-axis in the y-direction 
                              % of node i along the bridge span.

end


% Defining the orientation of each element in space (dx, dy and Le)

dx = L/(Nsup-1);         % Lenght of each element in the x-direction.
dy = zeros(Nsup-1,1);    % Vector for the dy lengths of the elements.
Le = zeros(Nsup-1,1);    % Vector for the total lengths of the elements.

for i = 1:Nsup-1;

dy(i) = deltay(i+1) - deltay(i);      % Length of element i in y-direction.

Le(i) = sqrt(dx*dx + dy(i)*dy(i));    % Total length of element i.

end

% Establishing transformation matrices according to the orientation of each
% of the elements along the superstructure.

ttrans = zeros(3,3,Nsup-1);   % Transformation matrix for the translational DOF's for a single node

trota  = zeros(3,3,Nsup-1);   % Transformation matrix for the rotational DOF's for a single node

Trsup  = zeros(12,12,Nsup-1); % Transformation matrix for an element, stored in a matrix array


for m = 1 : (Nsup-1)/2;     % Loop over the first half of the elements
    
    xx(m) = atan(dy(m)/dx);
    yy(m) = atan(dy(m)/dx);
    zz(m) = 0;              % No rotation of the z-axis
    
    xy(m) = (pi/2) - abs(atan(dy(m)/dx));
    yx(m) = (pi/2) + abs(atan(dy(m)/dx));
    
    zx(m) = pi/2;           % The z-axis is still oriented normal to the
    zy(m) = pi/2;           % x- and y-axis.
    xz(m) = pi/2;
    yz(m) = pi/2;
    
    ttrans(:,:,m) = [cos(xx(m)) cos(xy(m)) cos(xz(m));
                     cos(yx(m)) cos(yy(m)) cos(yz(m));
                     cos(zx(m)) cos(zy(m)) cos(zz(m))];
                 
                 
    trota(:,:,m) = [cos(xx(m)) cos(xz(m)) cos(xy(m));
                    cos(zx(m)) cos(zz(m)) cos(zy(m));
                    cos(yx(m)) cos(yz(m)) cos(yy(m))];
                
                
    Trsup([1 2 3],[1 2 3],m) = ttrans(:,:,m);
    Trsup([4 5 6],[4 5 6],m) = trota(:,:,m);
    Trsup([7 8 9],[7 8 9],m) = ttrans(:,:,m);
    Trsup([10 11 12],[10 11 12],m) = trota(:,:,m);
    
    % The transformation matrices for the first 12 elements are stored in
    % the matrix array as Tr(:,:,1-12).
    
end
    
    
for m = 13 : Nsup-1;    % Loop over the last half of the elements
    
    xx(m) = atan(dy(m)/dx);
    yy(m) = atan(dy(m)/dx);
    zz(m) = 0;              % No rotation of the z-axis
    
    xy(m) = (pi/2) + abs(atan(dy(m)/dx));
    yx(m) = (pi/2) - abs(atan(dy(m)/dx));
    
    zx(m) = pi/2;           % The z-axis is still oriented normal to the
    zy(m) = pi/2;           % x- and y-axis.
    xz(m) = pi/2;
    yz(m) = pi/2;
    
    ttrans(:,:,m) = [cos(xx(m)) cos(xy(m)) cos(xz(m));
                     cos(yx(m)) cos(yy(m)) cos(yz(m));
                     cos(zx(m)) cos(zy(m)) cos(zz(m))];
                 
                 
    trota(:,:,m) = [cos(xx(m)) cos(xz(m)) cos(xy(m));
                    cos(zx(m)) cos(zz(m)) cos(zy(m));
                    cos(yx(m)) cos(yz(m)) cos(yy(m))];
                
                
    Trsup([1 2 3],[1 2 3],m) = ttrans(:,:,m);
    Trsup([4 5 6],[4 5 6],m) = trota(:,:,m);
    Trsup([7 8 9],[7 8 9],m) = ttrans(:,:,m);
    Trsup([10 11 12],[10 11 12],m) = trota(:,:,m);
    
    % The transformation matrices for the last 12 elements are stored in
    % the matrix array as Tr(:,:,13-24).
    
end

% Then, a complete set of transformation matrices are established to refer
% the local element DOF's of each element in the floating bridge
% superstructure, to the global coordinate system. These transformation
% matrices may then be applied to the property matrices of the
% elements (mass and stiffness) to obtain these matrices related to global
% coordinates.

% % Nodal points
% 
% n = 1:Nsup;
% x = (0:1:Nsup-1)*dx;
% y = deltay;
% 
% % Elements
% 
% element_data = [ ...
%                1:1:Nsup-1,
%                1:1:Nsup-1,
%                2:1:Nsup  ];
% 
% m  = element_data(1,:);
% ni = element_data(2,:);
% nj = element_data(3,:);
% 
% 
% plotelements(m,ni,nj,x,y)
% plotnodes(n,x,y)
% title('Arch shape of the floating bridge model in xy-plane');



end

