%
%
% Transfer function for the fluid-structure system of the Bergsysund
% floating bridge model.
%
% A transfer function matrix array for the fluid-structure system is 
% developed. This transfer function relates the response spectral density
% to the wave spectral density. 
%
% Tfunc = H(w)*F(w)*H(w)'
%
% The H-matrix expresses the frequency dependent fluid-structure properties
% in terms of inverted mass, damping and stiffness contributions.
% The F-matrix is also a function of frequency and expresses the kinematics
% and spatial distribution of the wave field.
%
% The fluid-structure transfer function may be viewed as the spectrum
% counterpart of the dimensionless load-scaled FRF's. The diagonal terms
% express the frequency dependent auto-spectrums of the response
% parameters. And is consequently a functions dictating the sensitivity of
% the responses in each DOF. 
%
% Scaling of the fluid-structure transfer function with an appropriate wave
% field renders the statistical spectrum response of the system
%
%

% Degrees of freedom

ndofsup  =  150;
ndofpc   =   36;
ndofG    =  360;
npc      =    7;
ndofGred = ndofG - 9;


s      = 3;     % Spreading index
omega0 = 0;     % Mean wave angle of approach


dw   = 0.2;
wmax = 1;
Nw   = fix(wmax/dw);


[H] = Bergsoy_H_matrix(dw,Nw);  

[Fhydro] = Bergsoy_hydro_transfer_function(s,dw,Nw,omega0);

% Introducing boundary conditions at the end supports of the bridge span

k = [1 2 3 4 5 356 357 358 359];

Hred = H;
Fred = Fhydro;

Hred(k,:,:) = [];
Hred(:,k,:) = [];

Fred(k,:,:) = [];
Fred(:,k,:) = [];


F = zeros(size(Fred));

for i = 1:Nw;
    for m = 1:length(Fred);
        
        F(m,m,i) = Fred(m,m,i);
        
    end
end
    
    
% Transfer function for the fluid structure system

Tfunc = zeros(ndofGred,ndofGred,Nw);

for i = 1:Nw;
    
    
    Tfunc(:,:,i) = Hred(:,:,i)*F(:,:,i)*ctranspose(Hred(:,:,i));
       
end


% Extracting diagonal terms associated with response parameters of
% interest at each frequency step. (heave)

w = zeros(1,Nw);

% Response at mid-node (DOF160 for reduced system)

h160 = zeros(1,Nw);

% Response at mid-point at center pontoon (DOF178)

h178 = zeros(1,Nw);

% Response at L/4-Point (DOF64 for reduced system)

h64 = zeros(1,Nw);

% Response at mid-point of L/4-point pontoon (DOF82)

h82 = zeros(1,Nw);

% Response at L/8-Point (DOF16 for reduced system) 
h16 = zeros(1,Nw);

% Response at mid-point of L/8-point pontoon (DOF34)

h34 = zeros(1,Nw);



for i = 1:Nw;
    
    w(i) = i*dw;
    
    h160(i) = Tfunc(160,160,i);
    h178(i) = Tfunc(178,178,i);
    
    h64(i)  = Tfunc(64,64,i);
    h82(i)  = Tfunc(82,82,i);
    
    h16(i)  = Tfunc(16,16,i);
    h34(i)  = Tfunc(34,34,i);
    
end

% Plot of the responses at mid-point and at L/4-point

figure(2);
plot(w,h160,'b',w,h178,'r');
title(['Autospectrum Heave Mid-Point  - s = ',num2str(s)]);
xlabel('Frequency - [rad/s]');
ylabel('Autospectra Heave Response - [m^2/m^2]');
legend('Bridge Span Mid-Point','Centre Pontoon Mid-Point');

figure(3);
plot(w,h64,'b',w,h82,'r');
title(['Autospectrum Heave L/4-Point  - s = ',num2str(s)]);
xlabel('Frequency - [rad/s]');
ylabel('Autospectra Heave Response - [m^2/m^2]');
legend('Bridge Span L/4-Point','L/4-Point Pontoon Mid-Point');

figure(4);
plot(w,h16,'b',w,h34,'r');
title(['Autospectrum Heave L/8-Point  - s = ',num2str(s)]);
xlabel('Frequency - [rad/s]');
ylabel('Autospectra Heave Response - [m^2/m^2]');
legend('Bridge Span L/8-Point','L/8-Point Pontoon Mid-Point');

    



    













