
%
% Establishing the hydrodynamic transfer function for evaluation of
% coherence and phase properties of both the wave loading situation and the
% response.
%
% The aim is to develope a hydrodynamic transfer function for the elements
% of a floating bridge being in contact with the water. Developed for a 3D
% floating bridge model with Nsup = 25 nodes along the superstructure and
% with npc = 7 pontoons introduced which are modelled with four
% hydro-elastic elements and one connnector element. The elements are
% interpolated consistent with the floating bridge model elements. 4DOF's
% describes the displacement of the elements in the vertical & horizontal
% directions. While linear interpolation functions are used for surge and
% roll directions.
%
% The coherense properties of the wave loading is extracted from the
% hydrodynamic transfer function, while the coherence and phase spectrums
% are extracted from the fluid-structure transfer function.
%
% Input: Nw - number of frequency steps
%        dw - angular frequency step size
%         d - draft of the pontoons
%         n - direction angle step size
%    omega0 - mean direction of wave approach
%         s - spreading index
%     ndofG - number of global DOF's
%
%
%
% By Axel Wullf Wathne, 2012.
%

s = 3;
dw=0.01;
wmax=5;
Nw=fix(wmax/dw);
omega0=0;


% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

L    =  840;      % length of bridge in x-direction  
B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
tds  = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tws  = 0.01;      % thickness of side walls of the superstructure
Nsup = 25;        % number of nodes along the superstructure  



% Properties of the PC-sub system

Lp = 30;          % length of pontoon
Bp = 20;          % width of pontoon in the fluid
hp = 7;           % height of pontoon
td = 0.35;        % thickness of pontoon top and bottom deck
tw = 0.55;        % thickness of pontoon walls
Lc = 1.20;        % length of connector rod
ry   = 0.15;      % outer radius of connector rod, assumed circular      
tc   = 0.02;      % thickness of connector rod, assumed circular
N    = 6;         % number of nodal points of the pontoon-connector model


Ap = 2*(Bp*td+(hp-(2*td))*tw);  % Area of pontoon cross-section, assumed hollow quadratic section
Ac = pi*(2*ry*tc - tc^2);       % Area of connector cross-section, assumed hollow circular section 
As = (2*(h-tds-ts)*tws)+(B*(tds+ts)); % Area of superstructre cross-section, assumed hollow quadratic section [m2]


denp = 2500;                    % Density of concrete
denS = 7500;                    % Density of steel


g    = 9.81;                    % Gravitational constant
rhow = 1025;                    % Density of salt water


% Evaluation of the draft of a pontoon

% It is assumed that the weight of the overlying structure is equally
% distributed across the pontoons. Such that the weigth on a single pontoon
% is equal to the weight of three superstructure elements, the connector rod
% element and the two pontoon elements.


Lesup = L/(Nsup-1);

W  = (3*(Lesup*As*denS) + (Lp*Ap*denp) + (Lc*Ac*denS))*g; % Weight distributed to
                                                            % one pontoon from the
                                                            % above structure.

kB = rhow*g*Bp*Lp;       % Buoyancy stiffness 
                                                            
d  = W/kB;               % Draft of the pontoon  


ndofG  = 360;  % number of global DOF's
ndofel = 4;    % number of element DOF's in the vertical plane when using 
               % consistent interpolation functions
Ndofel = 12;   % DOF's of 3D-12DOF element
Nel    = 28;   % number of elements in contact with the fluid
Lep    = Lp/4; % length of elements modelling the pontoons
npc    = 7;    % number of pontoons




% Establishing the orientation in space for the seven sub-systems

% Defining the arch shape as function of the x-position of each node.

R    = 1300;   % Radius of the horizontal arch.
Nsup = 25;     % Nodes along the bridge span.
L    = 840;    % Length of bridge in x-direction

% Arch height at mid-point, deltamid.

hmid     = sqrt(R^2 - (L/2)^2);
deltamid = R - hmid;

% Vectors for the x- and y-postion of the nodes along the bridge
% superstructure.

x = (-L/2: L/(Nsup-1) : L/2);

y = zeros(1,length(x));

deltay = zeros(1,length(x));


% Postion of each node in the y-plane corresponding with x-position

for i = 1:length(x);

y(i) = sqrt(R^2 - x(i)^2);    % Function for a circle, defining the y-position 
                              % according to x-postion.
                        
deltay(i) = y(i) - hmid;      % The postion above the x-axis in the y-direction 
                              % of node i along the bridge span.

end


% Defining the positions of connection points between the arch bridge span
% and the pontoons in space.

xpos = [x(4) x(7) x(10) x(13) x(16) x(19) x(22)];
ypos = [deltay(4) deltay(7) deltay(10) deltay(13) deltay(16) deltay(19) deltay(22)];


% Defining the orientation of each element in space (dx, dy and Le)

dx = L/(Nsup-1);        % Lenght of each element in the x-direction.
dy = zeros(Nsup-1,1);   % Vector for the dy lengths of the elements.
Le = zeros(Nsup-1,1);   % Vector for the total lengths of the elements.


for i = 1:Nsup-1;       % Loop over the arch elements

dy(i) = deltay(i+1) - deltay(i);      % Length of element i in y-direction.

Le(i) = sqrt(dx*dx + dy(i)*dy(i));    % Total length of element i.


end


% Vector for the angles at the mid-node of the pontoon sub-systems relative
% to the global x-axis

xx=zeros(7,1);

% Inserting the respective angles
xx(1) = ((atan(dy(3)/dx))  + (atan(dy(4)/dx)))*0.5;
xx(2) = ((atan(dy(6)/dx))  + (atan(dy(7)/dx)))*0.5;
xx(3) = ((atan(dy(9)/dx))  + (atan(dy(10)/dx)))*0.5;
xx(4) = ((atan(dy(12)/dx)) + (atan(dy(13)/dx)))*0.5;
xx(5) = ((atan(dy(15)/dx)) + (atan(dy(16)/dx)))*0.5;
xx(6) = ((atan(dy(18)/dx)) + (atan(dy(19)/dx)))*0.5;
xx(7) = ((atan(dy(21)/dx)) + (atan(dy(22)/dx)))*0.5;

angle = zeros(1,Nel);

for i = 0:npc-1;  % Loop over the pontoons to apply the orientation of the
                  % pontoons to the elements making up the pontoon.
    
angle(1+4*i) = xx(i+1);
angle(2+4*i) = xx(i+1);
angle(3+4*i) = xx(i+1);
angle(4+4*i) = xx(i+1);

end


% Postion in space of the first node of the elements in contact with the
% water as xe and ye vectors.

xe = zeros(1,Nel);
ye = zeros(1,Nel);

% Defining the x-y-position of the elements that has their first nodes at
% the point of connection between the arch and pontoons.
xe(3)  = xpos(1);
xe(7)  = xpos(2);
xe(11) = xpos(3);
xe(15) = xpos(4);
xe(19) = xpos(5);
xe(23) = xpos(6);
xe(27) = xpos(7);

ye(3)  = ypos(1);
ye(7)  = ypos(2);
ye(11) = ypos(3);
ye(15) = ypos(4);
ye(19) = ypos(5);
ye(23) = ypos(6);
ye(27) = ypos(7);

for i = 0:npc-1; % Looping the pontoons to determine the x-y-position of 
                 % remaining elements of each pontoon.

xe(1+4*i) = xe(3+4*i) + 2*Lep*sin(xx(1+i));
xe(2+4*i) = xe(3+4*i) +   Lep*sin(xx(1+i));
xe(4+4*i) = xe(3+4*i) -   Lep*sin(xx(1+i));

ye(1+4*i) = ye(3+4*i) - 2*Lep*cos(xx(1+i));
ye(2+4*i) = ye(3+4*i) -   Lep*cos(xx(1+i));
ye(4+4*i) = ye(3+4*i) +   Lep*cos(xx(1+i));

end


% Writing a matrix to store the individual x & y position differences
% between pontoon elements m & n. The absolute values are determined.

% The loop is run over the top right corner of the X & Y matrices, as the
% difference in space between abs(m-n) is equal to abs(n-m).

X = zeros(Nel);
Y = zeros(Nel);

for m = 1:Nel;      % Loop over the pontoon elements
    for n = m:Nel;
        
        X(m,n) = abs(xe(m) - xe(n));
        Y(m,n) = abs(ye(m) - ye(n));
        
    end
end



% Defining the wave directional angle range and step size

nom = 0.05;         % angluar step size

Omega = omega0-(pi/4) : (nom*pi) : omega0+(pi/4);


% Determination of the scaling factor, Ns, for the spreading function 
% according to the spreading index, s.

if omega0 <= 0;
    
    omegaminus = - pi/2;
    omegaplus  =  (pi/2) + omega0;
    
else  % Which in turns implies omega0 > 0;
    
    omegaminus = -(pi/2) + omega0;
    omegaplus  =   pi/2;
    
end


% Integration of the cos-2s-distribution over the range of approach angles
% by the use of a numerical trapezoid integration method.
% The spreading function is only valid in the range of omegaminus-omegaplus
% and is set equal to zero for other approach angles.



Direc_init = zeros(1,length(Omega));

for i = 1:length(Omega);

if omegaminus <= Omega(i) <= omegaplus;
    
    Direc_init(i) = (cos (Omega(i) - omega0)).^(2*s);
    
else
    
    Direc_init(i) = 0;
    
end
end


SumDirec_init = trapz(Omega,Direc_init);


% Determination of the normalizing coefficient to ensure that the spreading
% function is integrated to unity over the approach angle domain

Ns = 1 / SumDirec_init;



% Defining the frequency intervall and step size

w  = zeros(Nw,1);   % Vector for storing the angular frequencies


% Matrix array for storing the hydrodynamic transfer function values for
% each frequency step.

Fmn = zeros(Ndofel,Ndofel,Nw,Nel,Nel);

Fhydro = zeros(ndofG,ndofG,Nw); 

% Vector to store the F values for each angular step Om
            
F = zeros(Ndofel,Ndofel,length(Omega),Nel,Nel);

% D-vectors determined for four interpolation functions consistent with the
% element formulation and the translational and rotational DOF's describing
% the vertical displacement along a beam element. The expressions in the
% D-matrices are obtained by analytical integration.

Dm = zeros(ndofel,1);       % Stored as column vectors
Dn = zeros(ndofel,1);


% Vector defining the DOF's of a 3D-12DOF element associated with the
% vertical motion.

vz = [3 6 9 12];

for i = 1:Nw;    % Loop over each frequency step, each frequency step 
                    % defines one set of Fmn matrices in the matrix array.
                    % The matrices computed for the frequency step w(i) are
                    % of size 4x4 (for the 4DOF element) and there is one
                    % matrix for each m-n-element combination.
    
    w(i) = i*dw;     % Angular frequency 
    
    
    for m = 1:Nel;      % Loop over the pontoon elements assemblying only 
        for n = m:Nel;  % the top right corner of the F and Fmn matrices.

            
            
            for j=1:length(Omega);  % Loop over the angular direction domain
                
                Om = Omega(j);      % Determine the angular value of the loop 

                % Writing the relative angles between the wave direction
                % and the orientation of elements m & n.
                
                Omrelm = abs(Om) - abs(angle(m));
                Omreln = abs(Om) - abs(angle(n));

km = sqrt(-1)*(1/g)*w(i)*abs(w(i))*cos(Omrelm);
kn = sqrt(-1)*(1/g)*w(i)*abs(w(i))*cos(Omreln);


Dm(1) = ((6/(km^3*Lep^2))-(12/(km^4*Lep^3)))*exp(km*Lep) - (1/km) + (6/(km^3*Lep^2)) + (12/(km^4*Lep^3)); 
Dm(2) = ((2/(km^3*Lep))-(6/(km^4*Lep^2)))*exp(km*Lep) - (1/km^2) + (4/(km^3*Lep)) + (6/(km^4*Lep^2));
Dm(3) = ((1/km)-(6/(km^3*Lep^2))+(12/(km^4*Lep^3)))*exp(km*Lep) - (6/(km^3*Lep^2)) - (12/(km^4*Lep^3));
Dm(4) = (-(1/km^2)+(4/(km^3*Lep))-(6/(km^4*Lep)))*exp(km*Lep) + (2/(km^3*Lep)) + (6/(km^4*Lep^2));

Dn(1) = ((6/(kn^3*Lep^2))-(12/(kn^4*Lep^3)))*exp(kn*Lep) - (1/kn) + (6/(kn^3*Lep^2)) + (12/(kn^4*Lep^3)); 
Dn(2) = ((2/(kn^3*Lep))-(6/(kn^4*Lep^2)))*exp(kn*Lep) - (1/kn^2) + (4/(kn^3*Lep)) + (6/(kn^4*Lep^2));
Dn(3) = ((1/kn)-(6/(kn^3*Lep^2))+(12/(kn^4*Lep^3)))*exp(kn*Lep) - (6/(kn^3*Lep^2)) - (12/(kn^4*Lep^3));
Dn(4) = (-(1/kn^2)+(4/(kn^3*Lep))-(6/(kn^4*Lep)))*exp(kn*Lep) + (2/(kn^3*Lep)) + (6/(kn^4*Lep^2));
  
  
% Importing the frequency dependent load-amplitude in heave

[q0h,q0hdim,wdim] = floating_bridge_3D_load_amplitude_heave(Bp,w(i));
 

% Running a loop over the DOF's of the element to allocate the terms in the
% [ndofel,ndofel]-matrix associated with elements m & n and with direction
% of approach step j.

for l = 1:ndofel;
    for p = 1:ndofel;

%F(vz(l),vz(p),j,m,n) = (Ns*(cos(Om - omega0))^(2*s))*(exp(sqrt(-1)*w(i)*abs(w(i))*(1/g)*(Y(m,n)*cos(Om)-X(m,n)*sin(Om))))*(conj(Dm(l))*(q0h^2)*(Dn(p)));

F(vz(l),vz(p),j,m,n) = (Ns*(cos(Om - omega0))^(2*s))*real(exp(sqrt(-1)*w(i)*abs(w(i))*(1/g)*(Y(m,n)*cos(Om)-X(m,n)*sin(Om))))*(conj(Dm(l))*(q0h^2)*(Dn(p)));



    end
end


            end
           
            % The terms of the [ndofel,ndofel]-matrix determined for the 
            % m-n combination in F are integrated over the wave-angle-of-approach
            % domain to determine the terms in the [ndofel,ndofel]-matrix
            % in Fmn.
            
            
            for k = 1:ndofel;
                for r = 1:ndofel;
                    
                    
                    Fmn(vz(k),vz(r),i,m,n) = trapz(Omega,F(vz(k),vz(r),:,m,n));
                    
                    Fmn(vz(k),vz(r),i,n,m) =  Fmn(vz(k),vz(r),i,m,n);
                
                end
            end
           
            
        end
    end

    % At this point a full matrix of Fmn is
    % completed for frequency step w(i).


% Importing the connectivity matrices linking the vertical translational
% DOF's of each of the pontoon elements to the global DOF's. The
% connectivity matrices are stored in a matrix array such that the 
% connectivity matrix linking the DOF's of element i are stored as
% ahydro(:,:,i). Dimensions [12 x ndofG x Nel]

[ahydro] = Bergsoy_connectivity_hydro_transfer(Ndofel,Nel,npc,ndofG);


% Assembly the complete hydrodynamic transfer function in terms of a matrix
% array where the matrices are of size [ndofG x ndofG] and the array has
% length equal to the number of frequency steps in the calculations.
 
    
    for m = 1:Nel;
        for n = 1:Nel;
        
        Fhydro(:,:,i) = Fhydro(:,:,i) + ahydro(:,:,m)'*Fmn(:,:,i,m,n)*ahydro(:,:,n);
        
        
        end
    end
end

% Writing vectors for evaluation of the frequency dependent load transfer
% at the mid-pontoon, L/4-pontoon and L/8-pontoon.

Q183 = zeros(1,Nw);     % Mid-pontoon (DOF183)
Q87  = zeros(1,Nw);     % L/4-pontoon (DOF87)
Q39  = zeros(1,Nw);     % L/8-pontoon (DOF39)

for i = 1:Nw;
    
    Q183(i) = Fhydro(183,183,i);
    Q87(i)  = Fhydro(87,87,i);
    Q39(i) = Fhydro(39,39,i);
    
end

figure(1)
plot(w,Q183);
title('Heave Load in Mid-Pontoon');

figure(2)
plot(w,Q87);
title('Heave Load in L/4-Pontoon');

figure(3)
plot(w,Q39);
title('Heave Load in L/8-Pontoon');
    

% Evaluation of the coherence spectrum for the wave loading 

CohFrFs = zeros(ndofG,ndofG,Nw);


for i=1:Nw;
    for r = 1:ndofG;
        for s = r:ndofG;
        
%         if r==s;
%             
%             CohFrFs(r,s,i) = 1;
%         else

CohFrFs(r,s,i) = (Fhydro(r,s,i)^2)/(Fhydro(r,r,i)*Fhydro(s,s,i));


CohFrFs(s,r,i) = CohFrFs(r,s,i);

        %end
        end
    end
end


% Coherence plots of heave variables as functions of position in space and
% frequency.

% Extracting cohernece properties of heave at mid-point of center pontoon


ndofQh = 5*npc;     % Number of loaded nodes in heave on the pontoons

Cohheave = zeros((ndofQh-1)/2 + 1,Nw); % Matrix for storing heave as function of 
                                       % spatial distribution and frequency
                             
nheave = 183;                % Node for determination of heave associated 
                             % with mid-point of the center pontoon

                             
% Numbering of the DOF's associated with heave at the pontoons prior to
% inclusion of the boundary conditions.

nodesm =zeros(npc,5);

for n = 0:npc-1;    % Loop over the pontoon sub-systems
    for k = 0:4;    % Loop over pontoon sub-system nodes

nodesm(n+1,k+1) = 27 + 6*k + 48*n;

    end
end

nodesv = zeros(1,ndofQh);   % Vector for storing the DOF numbers in order

nodesv(1:5)   = nodesm(1,1:5);
nodesv(6:10)  = nodesm(2,1:5);
nodesv(11:15) = nodesm(3,1:5);
nodesv(16:20) = nodesm(4,1:5);
nodesv(21:25) = nodesm(5,1:5);
nodesv(26:30) = nodesm(6,1:5);
nodesv(31:35) = nodesm(7,1:5);

                         
% Writing in the coherence properties as column vectors at each frequency
% step, w(i).
% The Cohheave matrix represents the Coherence properties of heave in the
% node associated with DOF "nheave" as related to the other loaded heave
% DOF's as function of frequency.

for i = 1:Nw;
    for j = 1:(ndofQh-1)/2 + 1;
        
        Cohheave(j,i) = CohFrFs(nheave,nodesv(j+17),i);
        
    end
end


% % Writing a vector for the x-positions of the pontoons
% 
% x = zeros(1,ndofQh);
% 
% 
% % Defining the x-y-position of the elements that has their first nodes at
% % the point of connection between the arch and pontoons.
% x(3)  = xpos(1);
% x(8)  = xpos(2);
% x(13) = xpos(3);
% x(18) = xpos(4);
% x(23) = xpos(5);
% x(28) = xpos(6);
% x(33) = xpos(7);
% 
% 
% for i = 0:npc-1; % Looping the pontoons to determine the x-y-position of 
%                  % remaining elements of each pontoon.
% 
% x(1+5*i) = x(3+5*i) + 2*Lep*sin(xx(1+i));
% x(2+5*i) = x(3+5*i) +   Lep*sin(xx(1+i));
% x(4+5*i) = x(3+5*i) -   Lep*sin(xx(1+i));
% x(5+5*i) = x(3+5*i) - 2*Lep*sin(xx(1+i));
% 
% end


 
%x = [0.8:0.1:1.2,1.8:0.1:2.2,2.8:0.1:3.2,3.8:0.1:4.2,4.8:0.1:5.2,5.8:0.1:6.2,6.8:0.1:7.2];

x = [1:0.1:1.2,1.8:0.1:2.2,2.8:0.1:3.2,3.8:0.1:4.2];

figure(4)
surfl(w,x,abs(Cohheave)); 
title('Coherence Spectrum for Wave Loading with Respect to the Centre Pontoon');
        

ndofGred = ndofG-9;

% Importing H-matrix

[H] = Bergsoy_H_matrix(dw,Nw);

% Introducing the boundary conditions of the model

k = [1 2 3 4 5 356 357 358 359]; 
 
   Fhred  = Fhydro;
   Hred   = H;
   

   Fhred(k,:,:) = [];
   Fhred(:,k,:) = [];

   Hred(k,:,:)  = [];
   Hred(:,k,:)  = [];



% Determination of transfer function for the fluid-structure system

Tfunc = zeros(ndofGred,ndofGred,Nw);

for i = 1:Nw;

Tfunc(:,:,i) = Hred(:,:,i)*Fhred(:,:,i)*ctranspose(Hred(:,:,i));

end


% Evaluation of the coherence spectrum for the response over the bridge span 

CohArAs = zeros(ndofGred,ndofGred,Nw);


for i=1:Nw;
    for r = 1:ndofGred;
        for s = r:ndofGred;
        
%         if r==s;
%             
%             CohFrFs(r,s,i) = 1;
%         else

CohArAs(r,s,i) = (Tfunc(r,s,i)^2)/(Tfunc(r,r,i)*Tfunc(s,s,i));


CohArAs(s,r,i) = CohArAs(r,s,i);

        %end
        end
    end
end

% Coherence plots of heave variables as functions of position in space and
% frequency.

% Extracting cohernece properties of heave at mid-point of center pontoon


ndofH = 23;     % Number of free nodes in heave over the bridge span

Cohheave2 = zeros((ndofH-1)/2 + 1,Nw); % Matrix for storing heave as function of 
                                       % spatial distribution and frequency
                             
nheave2 = 160;                % Node for determination of heave associated 
                             % with mid-point of the center pontoon

                             
% Numbering of the DOF's associated with heave over the bridge span after
% the boundary conditions are introduced

nodes = [4 10 16 52 58 64 100 106 112 148 154 160 196 202 208 244 250 256 292 298 304 340 346];



                         
% Writing in the coherence properties as column vectors at each frequency
% step, w(i).
% The Cohheave matrix represents the Coherence properties of heave in the
% node associated with DOF "nheave" as related to the other loaded heave
% DOF's as function of frequency.


for i = 1:Nw;
    for j = 1:(ndofH-1)/2+1;
        
        Cohheave2(j,i) = CohArAs(nheave2,nodes(j+11),i);
        
    end
end

x2 = 0:11;

figure(5)
surfl(w,x2,abs(Cohheave2)); 
title('Coherence Spectrum for Heave Response with Respect to the Mid-Point');


% Phase spectrum

Phas = zeros(ndofGred,ndofGred,Nw);


for i=1:Nw;
    for r = 1:ndofGred;
        for s = r:ndofGred;
        
%         if r==s;
%             
%             CohFrFs(r,s,i) = 1;
%         else

Phas(r,s,i) = atan((-imag(Tfunc(r,s,i)))/(real(Tfunc(r,s,i))));


Phas(s,r,i) = Phas(r,s,i);

        %end
        end
    end
end

% Extracting phase properties of heave response at mid-point of center pontoon


Phase = zeros((ndofH-1)/2 + 1,Nw); % Matrix for storing heave as function of 
                                   % spatial distribution and frequency
                             
nheave2 = 160;                % Node for determination of heave associated 
                             % with mid-point of the center pontoon

                             
for i = 1:Nw;
    for j = 1:(ndofH-1)/2 + 1;
        
        Phase(j,i) = Phas(nheave2,nodes(j+11),i);
        
    end
end
    
figure(2)
surfl(w,x2,Phase); 
title('Phase Spectrum for Heave Response with Respect to the Mid-Point');





