function [Direc, Ns, SumDirec, Omega] = cos_directional_spreading_function(nom,omega0,s)

% Cosine-2s-distribution
%
% A function to determine the directional spreading function. The spreading
% function is further applied to a wave spectrum to develope a directional
% wave spectrum.
% 
% Input: Spreading index: s
%        Mean wave angle of approach: omega0
%        Angular step size: n
%
% The range of wave direction is maximum and in the range of -pi/2<omega<pi/2
% for a mean wave angle of 0. 
%
% By: Axel Wullf Wathne, 2012



n = nom;

% Determination of the range of approach angles based on the mean wave
% angle of approach

if omega0 <= 0;
    
    omegaminus = - pi/2;
    omegaplus  =  (pi/2) + omega0;
    
else  % Which in turns implies omega0 > 0;
    
    omegaminus = -(pi/2) + omega0;
    omegaplus  =   pi/2;
    
end


% Integration of the cos-2s-distribution over the range of approach angles
% by the use of a numerical trapezoid integration method.
% The spreading function is only valid in the range of omegaminus-omegaplus
% and is set equal to zero for other approach angles.

Omega = -(pi/2) : (n*pi) : (pi/2);

Direc_init = zeros(1,length(Omega));

for i = 1:length(Omega);

if omegaminus <= Omega(i) <= omegaplus;
    
    Direc_init(i) = (cos (Omega(i) - omega0)).^(2*s);
    
else
    
    Direc_init(i) = 0;
    
end
end


SumDirec_init = trapz(Omega,Direc_init);


% Determination of the normalizing coefficient to ensure that the spreading
% function is integrated to unity over the approach angle domain

Ns = 1 / SumDirec_init;



% Establishing the final spreading function as determined by the input
% spreading index, s, and the mean wave angle of approach, omega0

Direc = zeros( 1 , (1/n)+1); 



for i = 1 : (1/n)+1;
    
    

if omegaminus <= Omega(i) <= omegaplus;

    Direc(i) = Ns * (cos (Omega(i) - omega0)).^(2*s);

else
    
    Direc(i) = 0;
    
end


end



% Direc = Ns * (cos (Omegarange - omega0)).^(2*s);


% Control of the calculated normalizing coefficient is carried out. The
% integral should be, or very close to, unity

SumDirec = trapz (Omega , Direc);

end







    















    
    
