function [myr] = floating_bridge_3D_interpolation_added_mass_sway_roll(w,Bp,g)

% Interpolation function to determine the coupled dimensionless hydrodynamic
% added mass assosiated with motion in sway and roll.
%
% The values for the hydrodynamic added mass coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w*sqrt(B/2*g). The other containing the corresponding values for
% the dimensionless added mass in heave motion.
%
% The dimensionless hydrodynamic mass for coupled sway and roll motion is 
% made dimensionless by the division myr/(rhow*Awp*B).
%
% The dimensionless hydrodynamic coefficents are picked from a graphical
% plot of hydrodynamic coefficients presented in "Frequency domain analysis
% of a foating bridge exposed to irregular short-crested waves" by Langen.
% The values are derived from Vugts, J.H. "The hydrodynamic coefficients 
% for swaying, heaving and rolling cylinders in a free surface".
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%       wnorm = Vector of dimensionless angular frequency
%   myrvalues = Vector of hydrodynamic added mass coefficients for combined sway-roll motion
%         myr = Output dimensionless hydrodynamic added mass coefficents for
%               the coupled sway-roll motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.



myr = zeros(1,length(w));

for k=1:length(w);
    

    w1normi(k) = abs(w(k)*sqrt(Bp/(2*g)));  %Normalised absolute value of
                                            % angular frequency input

if  w1normi(k) > 2.0;
    
        myr(k) = 0.003;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.125 0.25 0.375 0.50 0.5625 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
myrvalues  =  [0.025 0.03 0.035 0.04 0.045 0.045 0.04 0.02 0.00 -0.0125 -0.02 -0.02 -0.015 -0.0125 -0.01 -0.005 0.00 0.0025];


myr(k) = interp1(wnorm,myrvalues,w1normi(k));

end

end

end
