function [q0h,q0hdim,wdim] = floating_bridge_3D_load_amplitude_heave(Bp,w)

%
% Function for the load amplitude in heave on a beam element (pontoon)
% Developed for a width-draft ratio Bp/d - 4 (approximately)
%
% Input:  Bp - width of beam element in fluid
%          w - vector of angular frequencies
%
% Output; q0 - vector of load amplitude per unit length [N/m]
%      q0dim - vector of dimensionless load amplitude per unit length
%       wdim - vector of dimensionless angular frequency
%
%
% The load amplitude is calculated per unit length of a floating beam. The
% width, Bp, of the beam is included in the calculations  of the floating 
% beam. The load amplitude represents a maximum amplitude of a harmonic 
% wave excitation load on a floating body in heave,according to the 
% frequency of motion. 
%
% It is seen that as the angular frequency is zero, the dimensionless force
% amplitude is equal to unity, which represents a structura that follows
% the elevation of the sea surface for long-period waves. As the frequency
% increases, the load amplitude decreases as less force is transferred to
% the floating body at higher frequencies. 
%
%
%
% By Axel Wullf Wathne, 2012.
%
%



rhow = 1025;                  % density of water
g    = 9.81;                  % gravitational acceleration
a    = 1;                     % wave amplitude


k      = zeros(length(w),1);  % vector for storing wave numbers
q0h    = zeros(length(w),1);  % vector for storing load amplitudes
q0hdim = zeros(length(w),1);  % vector for storing dimensionless load amplitude
wdim   = zeros(length(w),1);  % vector for storing dimensionless frequency 



for j = 1:length(w);
        
        
          k(j) = (abs(w(j))^2)/g;            % wave number, deep water
    

    wdim(j)  = abs(w(j))*(sqrt(Bp/(2*g)));   % dimensionless angular frequency  

if  wdim(j) > 2.0;
    
        q0hdim(j) = 0.03;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic load amplitude coefficients in sway.

wdimvalues = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.250 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
qzvalues  =  [1.00 0.963 0.875 0.80 0.70 0.625 0.55 0.463 0.40 0.338 0.275 0.20 0.1625 0.1375 0.1125 0.0875 0.075];


q0hdim(j) = interp1(wdimvalues,qzvalues,wdim(j),'spline');


end

q0h(j)    = q0hdim(j)*rhow*g*Bp*a;

end

% Plot of the load amplitude as function of frequency

% figure(1);
% plot(wdimvalues,qzvalues);
% title('Dimensionless Load Amplitude - Heave');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - q0h/(rhow*g*Bp*a');
% 
% figure(2);
% plot(w,q0h);
% title('Load Amplitude - Heave');
% xlabel('Frequency - (rad/s)');
% ylabel('Load amplitude - q0h [N/m]');
% 
% figure(3);
% plot(w,q0hdim);
% title('Dimensionless Load Amplitude - Heave');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - q0h/(rhow*g*Bp*a');


end


