function [q0r,q0rdim,wdim] = floating_bridge_3D_load_amplitude_roll(Bp,w)

%
% Function for the load amplitude in roll on a beam element (pontoon)
% Developed for a width-draft ratio Bp/d - 4 (approximately)
%
% Input:  Bp - width of beam element in fluid
%         dx - length of beam element i fluid
%          w - vector of angular frequencies
%
% Output;
%        qr0 - vector of load amplitude per unit length [N/m]
%     q0rdim - vector of dimensionless load amplitude per unit length
%       wdim - vector of dimensionless angular frequency
%
%
% The load amplitude is calculated per unit length of a floating beam. The
% width, Bp, of the beam is included in the calculations as well as the
% draft, d, of the floating beam. The load amplitude represents a maximum
% amplitude of a harmonic wave excitation load on a floating body in heave,
% according to the frequency of motion. 
%
% The load amplitude is determined for a unit amplitude of the oncoming
% waves, a = 1m.
%
%
% By Axel Wullf Wathne, 2012.
%
%


rhow = 1025;                  % density of water
g    = 9.81;                  % gravitational acceleration
a    = 1;                     % wave amplitude



k      = zeros(length(w),1);  % vector for storing wave numbers
q0r    = zeros(length(w),1);  % vector for storing load amplitudes
q0rdim = zeros(length(w),1);  % vector for storing dimensionless load amplitude
wdim   = zeros(length(w),1);  % vector for storing dimensionless frequency 



for j = 1:length(w);
        
        
          k(j) = (abs(w(j))^2)/g;            % wave number, deep water
    

    wdim(j)  = abs(w(j))*(sqrt(Bp/(2*g)));   % dimensionless angular frequency  

if  wdim(j) > 2.0;
    
        q0rdim(j) = 0.0;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic load amplitude coefficients in sway.

wdimvalues = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
qrvalues  =  [0.70 0.70 0.675 0.650 0.55 0.450 0.35 0.250 0.15 0.100 0.05 0.025 0.015 0.01 0.005 0.001 0.00];


q0rdim(j) = interp1(wdimvalues,qrvalues,wdim(j),'spline');


end

q0r(j)    = q0rdim(j)*rhow*g*(Bp/12)*k(j)*a;

end

% Plot of the load amplitude as function of frequency

% figure(1);
% plot(wdimvalues,qrvalues);
% title('Dimensionless Load Amplitude - Roll');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - q0r/((rhow*g*Bp*k*a)/12)');
% 
% figure(2);
% plot(w,q0r);
% title('Load Amplitude - Roll');
% xlabel('Frequency - (rad/s)');
% ylabel('Load amplitude - q0r [Nm/m]');
% 
% figure(3);
% plot(w,q0rdim);
% title('Dimensionless Load Amplitude - Roll');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - q0r/((rhow*g*Bp*k*a)/12)');
% % 


end

