function [q0s,q0sdim,wdim] = floating_bridge_3D_load_amplitude_sway(dx,Bp,w)

%
% Function for the load amplitude in sway on a beam element (pontoon)
% Developed for a width-draft ratio Bp/d - 4 (approximately)
%
% Input:  Bp - width of beam element in fluid
%         dx - length of beam element i fluid
%          w - vector of angular frequencies
%
% Output;
%        qs0 - vector of load amplitude per unit length [N/m]
%     q0sdim - vector of dimensionless load amplitude per unit length
%       wdim - vector of dimensionless angular frequency
%
%
% The load amplitude is calculated per unit length of a floating beam. The
% width, Bp, of the beam is included in the calculations as well as the
% draft, d, of the floating beam. The load amplitude represents a maximum
% amplitude of a harmonic wave excitation load on a floating body in heave,
% according to the frequency of motion. 
%
% The load amplitude is determined for a unit amplitude of the oncoming
% waves, a = 1m.
%
%
% By Axel Wullf Wathne, 2012.
%
%


rhow = 1025;                  % density of water
g    = 9.81;                  % gravitational acceleration
Awp  = Bp*dx;                 % water plane area
a    = 1;                     % wave amplitude



k      = zeros(length(w),1);  % vector for storing wave numbers
q0s    = zeros(length(w),1);  % vector for storing load amplitudes
q0sdim = zeros(length(w),1);  % vector for storing dimensionless load amplitude
wdim   = zeros(length(w),1);  % vector for storing dimensionless frequency 



for j = 1:length(w);
        
        
          k(j) = (abs(w(j))^2)/g;            % wave number, deep water
    

    wdim(j)  = abs(w(j))*(sqrt(Bp/(2*g)));   % dimensionless angular frequency  

if  wdim(j) > 2.0;
    
        q0sdim(j) = 0.1;
        
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic load amplitude coefficients in sway.

wdimvalues = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
qyvalues  =  [1.60 1.65 1.675 1.70 1.65 1.525 1.375 1.150 0.85 0.650 0.45 0.350 0.30 0.20 0.175 0.150 0.125];


q0sdim(j) = interp1(wdimvalues,qyvalues,wdim(j),'spline');


end

q0s(j)    = q0sdim(j)*rhow*g*Awp*k(j)*a;

end

% Plot of the load amplitude as function of frequency

% figure(1);
% plot(wdimvalues,qyvalues);
% title('Dimensionless Load Amplitude - Sway');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - q0s/(rhow*g*Awp*k*a');
% 
% figure(2);
% plot(w,q0s);
% title('Load Amplitude - Sway');
% xlabel('Frequency - (rad/s)');
% ylabel('Load amplitude - q0s [N/m]');
% 
% figure(3);
% plot(w,q0sdim);
% title('Dimensionless Load Amplitude - Sway');
% xlabel('Dimensionless frequency - w*sqrt(Bp/2g)');
% ylabel('Dimensionless load amplitude - q0s/(rhow*g*Awp*k*a');


end

